import { Job } from "../models/job";
import { Sidebar } from "./sidebars";
import { Bar } from "./bars";
import set_event_watcher from "../wishlist";
import { scrollToTop } from "../scrolltotop";
function SortMultiValues(entries) {
    let array = []
    for (let i = 0; i < entries.length; i++) {
        array.push(entries[i])
    }
    return array
}

export const JobCollection = Backbone.Collection.extend({
    url: `${dp_args.restUrl}wp/v2/jobs`,

    model: Job,
    perPage: 10,
    currentPage: 1,
    totalPages: 1,
    id: null,
    totalItems: 10,
    activeTerm: null,
    activeTermTaxonomy: null,
    initialize: function (options) {
        this.eventEmitter = options.eventEmitter;
        if (dp_args.activeTerm) {
            this.activeTerm = dp_args.activeTerm;
            this.activeTermTaxonomy = dp_args.activeTermTaxonomy;
        }


    },
    goToNextPage: function () {
        this.fetchJobs();
        if (this.currentPage < this.totalPages) {
            this.currentPage++;
            this.fetchJobs();
        }
    },
    goToPreviousPage: function () {

        if (this.currentPage > 1) {

            this.currentPage--;
            this.fetchJobs();
        }
    },

    updatePagination: function (totalJobs, perPage = 10, currentPage = 1, ID = 'pagination') {
   
        let totalPageCount = Math.ceil(totalJobs / perPage);
        if (jQuery("#tmpl-pagination-template").length) {
            let template = wp.template('pagination-template');
            let data = {
                pages: Array.from({ length: totalPageCount }, (v, i) => i + 1),
                currentPage: currentPage,
                form_id: ID,
            };
            console.log(totalJobs, perPage, currentPage,ID);
            if (template) {
                let paginationHTML = template(data); // Render HTML with template

                jQuery("#pagination_" + ID).html(paginationHTML);
                this.eventEmitter.emit('updatePagination');
                //    setPaginationEvent()
                this.setPaginationEvents();
            }
        }
    },

    getShortcodeFormData: function (form) {

        const data = new FormData(form);


        const trimCommasAndWhitespace = (str) => {

            return str.trim().split(',').filter(item => item).join(',');
        }


        let obj = {};


        obj['city'] = data.get('city')
        obj['orderby'] = data.get('orderby')
        obj['order'] = data.get('order')
        obj['jobcategory'] = SortMultiValues(data.getAll('jobcategory')).toString();
        obj['jobcategory'] = SortMultiValues(data.getAll('jobcategory_jobcategory_terms')).toString();
        obj['job_type'] = SortMultiValues(data.getAll('job_type')).toString();
        obj['form_of_employment_terms'] = SortMultiValues(data.getAll('job_form_of_employment_job_form_of_employment_terms')).toString()
        obj['working_time_terms'] = SortMultiValues(data.getAll('job_working_time_job_working_time_terms')).toString()
        obj['s'] = data.get('s');
        obj['per_page'] = data.get('per_page');
        obj['distance'] = data.get('distance');
        obj['latitude'] = data.get('latitude');
        obj['longitude'] = data.get('longitude');
        obj['dates'] = data.get('dates');
        obj['company_id'] = data.get('company_id');

        if (dp_args && dp_args['activeTerm']) {
            obj['jobcategory'] = trimCommasAndWhitespace(obj['jobcategory'] = obj['jobcategory'] + ',' + dp_args['activeTerm']);
            obj['activeTerm'] = dp_args['activeTerm'];
        }

        if (dp_args && dp_args['activeTermTaxonomy']) {
            obj['activeTermTaxonomy'] = dp_args['activeTermTaxonomy'];
        }


        return Object.fromEntries(Object.entries(obj).filter(([_, v]) => v != null && v != ''));

    },

    getFormData: function (form) {
        const data = new FormData(form);
        const trimCommasAndWhitespace = (str) => {
            return str.trim().split(',').filter(item => item).join(',');
        }

        let obj = {};

        obj['select_jobcategory'] = SortMultiValues(data.getAll('jobcategory')).toString();
        obj['select_job_form_of_employment'] = SortMultiValues(data.getAll('job_form_of_employment')).toString();
        obj['select_job_type'] = SortMultiValues(data.getAll('job_type')).toString();
        obj['select_job_working_time'] = (SortMultiValues(data.getAll('job_working_time')).toString());
        obj['orderby'] = data.get('orderby')
        obj['order'] = data.get('order')
        obj['jobcategory'] = SortMultiValues(data.getAll('jobcategory_jobcategory_terms')).toString();
        obj['job_type'] = SortMultiValues(data.getAll('job_type_job_type_terms')).toString();
        obj['form_of_employment_terms'] = SortMultiValues(data.getAll('job_form_of_employment_job_form_of_employment_terms')).toString()
        obj['working_time_terms'] = SortMultiValues(data.getAll('job_working_time_job_working_time_terms')).toString()
        obj['s'] = data.get('s');
        obj['per_page'] = data.get('per_page');
        obj['distance'] = data.get('distance');
        obj['latitude'] = data.get('latitude');
        obj['longitude'] = data.get('longitude');
        obj['dates'] = data.get('dates');

        if (dp_args && dp_args['activeTerm']) {
            obj['jobcategory'] = trimCommasAndWhitespace(obj['jobcategory'] = obj['jobcategory'] + ',' + dp_args['activeTerm']);
        }
        return Object.fromEntries(Object.entries(obj).filter(([_, v]) => v != null && v != ''));
    },

    setContainers(id) {

        this.id = id;
        this.pagination = document.getElementById('pagination-' + this.id);
        this.outputContainer = document.getElementById('dp-output-' + this.id);
    },
    handle_job(data, ID, event) {
        self = this;


        this.currentPage = data.page
        console.log(ID)
        this.setContainers(ID);
        if (event) {
            if (event.name == 'dates') {
                this.updateSidebar(data, ID)
            }
            if (event.tagName == 'FORM') {
                this.updateSidebar(data, ID)
            }
            //jobs.updateSidebar(data, ID)
        }

        const successFunc = function (collection, response, options) {
            console.log(collection, response, options, data);

            self.eventEmitter.emit('updateJobs', data);
            return data;
        }.bind(ID);

        const errorFunc = function (collection, response, options) {
            console.error('Error:', options);
        }.bind(ID);

        const completeFunc = function (xhr, textStatus) {
            set_event_watcher();
            self.updatePagination(xhr.getResponseHeader('x-wp-total'), data.per_page, self.currentPage, this);
            self.updateCount(xhr.getResponseHeader('x-wp-total'), data, ID);
        }.bind(ID);
        data.ID = ID

        self.fetch({
            data: jQuery.param({ ...data }),
            beforeSend: function (xhr) { },
            success: successFunc,
            error: errorFunc,
            complete: completeFunc
        });
    },
    setPaginationEvents: function () {
        self = this;
        let paginationElements = document.querySelectorAll('.pagination ul li span');

        Array.from(paginationElements).forEach((elem) => {

            elem.addEventListener('click', function (e) {
                let clickedPage = this.getAttribute('data-page');
                if (clickedPage) {

                    const pagination_ID = this.getAttribute('data-id');

                    const ID = pagination_ID.split('pagination_')[0]

                    const dpForms = document.querySelectorAll('.dp-form-' + ID);

                    let combinedResult = {};
                    let ShData = self.getShortcodeFormData(dpForms[0])

                    Array.from(dpForms).forEach((dpForm) => {

                        let result = self.getFormData(dpForm)
                        combinedResult = Object.assign(combinedResult, result);

                    });
                    combinedResult = Object.assign(combinedResult, ShData);


                    combinedResult['page'] = parseInt(clickedPage);

                    self.handle_job(combinedResult, ID, e.target);
                    scrollToTop(document.getElementById('dp-output-'+ ID))
                  
                }
            });
        });
    },

    parse: function (response, options) {

        var totalItems = options.xhr.getResponseHeader('X-WP-Total');
        this.totalItems = parseInt(totalItems);


        var filter_count = document.getElementById('filter_count');
        if (filter_count) filter_count.innerHTML = totalItems

        if (filter_count && this.pagination) {

            this.outputContainer.innerHTML = '';
            this.pagination.innerHTML = ''
            let jobHTML = '';
            response.forEach(job => {
                jobHTML = jobHTML + job.rendered_job_item; // Assuming 'rendered_job_item' is the HTML field

            });
            this.outputContainer.innerHTML = jobHTML;
        } else {
            this.outputContainer.innerHTML = '';
            let jobHTML = '';
            response.forEach(job => {
                jobHTML = jobHTML + job.rendered_job_item; // Assuming 'rendered_job_item' is the HTML field

            });
            this.outputContainer.innerHTML = jobHTML;
        }
    },
    fetchJobs: function (data) {


        this.fetch({
            data: jQuery.param(data),
            processData: true,   // jQuery will convert data to a query string
            beforeSend: function (xhr) {

            },
            success: (collection, response, options) => {
                // Update totalPages from the response headers

                this.updatePagination(options.xhr.getResponseHeader('X-WP-Total'), 10)


                parent_id = getOpenedAccordion()



                this.updateSidebar(data, parent_id)
            },
            error: function (collection, response, options) {
                console.error('Error:', options);
            }
        });
    },
    updateCount: function (totalJobs, data, ID) {
        let countEl = document.getElementById('count_' + ID);
        if (countEl) {
            countEl.textContent = totalJobs;
        }
    }
});