/**
 * 
 * @param {*} inputElement 
 * @param {*} options 
 */
const GooglePlacesAutocompleteWrapper = class GooglePlacesAutocomplete {
    constructor(inputElement, options = {}) {
        this.inputElement = inputElement;
        this.cityElement = document.getElementById('city');
        this.zip = document.getElementById('zip');
        this.latitudeElement = document.getElementById('latitude');
        this.longitudeElement = document.getElementById('longitude');
        this.CityclearButton = document.getElementById('CityclearButton');
        var options = {
            componentRestrictions: { country: 'de' },
            region: 'de',
            language: 'de',
            types: ['geocode'],
            suppressDefaultUI: false,
            fields: ['address_components', 'geometry', 'adr_address'],

        };
        this.autocomplete = new google.maps.places.Autocomplete(inputElement, options);

        this.autocomplete.addListener('place_changed', this.onPlaceChanged.bind(this));
        this.inputElement.addEventListener('change', this.toggleClearButton.bind(this));


        this.CityclearButton.addEventListener('click', this.clearCityBox.bind(this));


    }

    toogleButtonBar() {

        if (this.inputElement.value.length > 0) {
            document.getElementById('get_current_position_wrapper').style.display = 'none';
        }
    }
    onPlaceChanged() {
        var place = this.autocomplete.getPlace();
        if (place && place.geometry && place.address_components) {
   
   
            var city = place.address_components.filter(ac => ~ac.types.indexOf('locality'))[0].long_name;
            var zip = place.address_components.filter(ac => ~ac.types.indexOf('postal_code'))[0].long_name;
            if (this.zip) {
                this.zip.value = zip;
            }
          
            var lat = place.geometry.location.lat();
            var lng = place.geometry.location.lng();
            this.cityElement.value = city;
            this.latitudeElement.value = lat;
            this.longitudeElement.value = lng;
            this.inputElement.value = city;
            this.toggleClearButton();
        }

    }
    getCurrentPosition() {
        let self = this;
        navigator.geolocation.getCurrentPosition(function (location) {
            var lat = location.coords.latitude;
            var lng = location.coords.longitude;
            var geocoder = new google.maps.Geocoder();
            var latlng = new google.maps.LatLng(lat, lng);
            geocoder.geocode({ 'latLng': latlng, 'language': 'de' }, function (results, status) {
                console.log(results, status);
                if (status == google.maps.GeocoderStatus.OK) {

                    if (results[0]) {
                        var user_city = results[0].address_components.filter(ac => ~ac.types.indexOf('locality'))[0].long_name
                        document.getElementById('city').value = user_city;
                        document.getElementById('searchInput').value = user_city;
                        document.getElementById('latitude').value = lat;
                        document.getElementById('longitude').value = lng;
                        self.toogleButtonBar();

                    }
                }
            });
        });


    }

    clearCityBox(event) {
        console.log('clearCityBox');
        var searchBox = document.getElementById('searchInput');
        var clearButton = document.getElementById('CityclearButton');


        clearButton.style.display = 'none';
        searchBox.value = '';
        clearButton.style.background = 'blue';


        this.cityElement.value = '';
        this.latitudeElement.value = '';
        this.longitudeElement.value = '';
        this.inputElement.value = '';


    }

    toggleClearButton() {
        console.log('toggleClearButton');
        var searchBox = document.getElementById('searchInput');
        var clearButton = document.getElementById('CityclearButton');
        if (searchBox.value.length > 0) {
            // 
        } else {

        }
        clearButton.style.display = 'inline-block';
    }


}





// Call the function when the document is ready
jQuery(document).ready(function () {

    let GooglePlace = new GooglePlacesAutocompleteWrapper(document.getElementById('searchInput'));
    document.getElementById('searchInput').addEventListener('focus', function (event) {

        if (event.target.value === '') {
            document.getElementById('get_current_position_wrapper').style.display = 'block';
        }

    });

    if (GooglePlace.inputElement.value.length > 0) {
        GooglePlace.toggleClearButton();
    }

    document.addEventListener('click', function (e) {
        if (e.target.id != 'searchInput') {
            if (e.target.id === 'get_current_position') {
                GooglePlace.getCurrentPosition();
                var clearButton = document.getElementById('CityclearButton');
                clearButton.style.display = 'inline-block';
            }


            document.getElementById('get_current_position_wrapper').style.display = 'none';
        }
    });

});


