<?php

class cf7_ex
{
  /**
   * Retrieves all ACF field groups associated with a specific custom post type.
   *
   * @param string $cpt The custom post type to retrieve field groups for.
   * @return array An array containing the field groups and their associated fields.
   */
  public function get_acf_field_groups_by_cpt($cpt)
  {

    $result = array(
      'fields' => []
    );
    $acf_field_groups = acf_get_field_groups();
    foreach ($acf_field_groups as $acf_field_group) {

      foreach ($acf_field_group['location'] as $group_locations) {
        foreach ($group_locations as $rule) {

          if ($rule['param'] == 'post_type' && $rule['operator'] == '==' && $rule['value'] == $cpt) {

            $result['fields'] = array_merge($result['fields'], acf_get_fields($acf_field_group));


          }

        }

      }

    }

    return $result;
  }

  //$groups = acf_get_field_groups(array('post_type' => 'your-post-type'));
  /**
   * Builds the tags for the current form.
   *
   * @return void
   */
  public function build_tags()
  {
    $fields = $this->get_acf_field_groups_by_cpt('job')['fields'];
    foreach ($fields as $field) {

      wpcf7_add_form_tag(
        'lead_' . $field['name'],
        array($this, 'wpcf7_current_url_form_tag_handler'),
        array(
          'name-attr' => true
        )
      );
    }
    wpcf7_add_form_tag(
      'acf',
      array($this, 'acf_form_tag_handler'),
      array(
        'name-attr' => true
      )
    );

  }
  /**
   * Retrieves the Advanced Custom Fields key for a given field name.
   *
   * @param string $field_name The name of the field to retrieve the key for.
   * @return string|bool The ACF key for the given field name, or false if it cannot be found.
   */
  public function get_acf_key($field_name)
  {
    $field = get_field_object($field_name);

    if (isset($field['key'])) {
      return $field['key'];
    } else {
      return false;
    }
  }
  /**
   * Retrieves the post ID from the URL if it exists and is not empty.
   * 
   * @return int The post ID from the URL, or 0 if it does not exist or is empty.
   */
  private function get_post_ID_from_url()
  {

    if (isset($_GET['post_id']) && $_GET['post_id']) {
      return intval($_GET['post_id']);
    }
  }



  // Parse the shortcode in the frontend
  /* public function acf_form_tag_handler($tag)
   {

     $field = get_field_object($tag['raw_name']);

     if ($field['type'] == 'checkbox') {
       $template = apply_filters('wp_leadgen_template_path', 'form/fields/checkbox.twig');
       //required:true 
       $post_ID = $this->get_post_ID_from_url();
       $field["post_id"] = $post_ID;
       $field["value"] = get_post_meta($field['post_id'], $field['name'], True);


       return Timber::compile($template, $field);
     }

     if ($field['type'] == 'select') {
       $post_ID = $this->get_post_ID_from_url();
       $field["post_id"] = $post_ID;
       $field["value"] = get_post_meta($field['post_id'], $field['name'], True);

       $template = apply_filters('wp_leadgen_template_path', 'form/fields/select.twig');
       return Timber::compile($template, $field);
     }

   }
     */

  // Parse the shortcode in the frontend
  /**
   * Handles the current URL form tag for the Contact Form 7 plugin.
   *
   * @param array $tag The form tag to be processed.
   * @return string The processed form tag.
   */
  public function wpcf7_current_url_form_tag_handler($tag)
  {
    global $wp;
    $name = str_replace('lead_', '', $tag['type']);
    $field = acf_get_field($name);

    return $this->switch_types($field['type'], $field);

  }
  /**
   * Switches between different types of fields and returns the corresponding HTML input or select element.
   *
   * @param string $type The type of field to switch to.
   * @param array $field An array containing the field's type and name.
   * @return string The corresponding HTML input or select element.
   */
  function switch_types($type, $field)
  {

    /*
        Text: text
        Textarea: textarea
        Number: number
        Email: email
        URL: url
        Password: password
        Wysiwyg Editor: wysiwyg
        Image: image
        File: file
        Select: select
        Checkbox: checkbox
        Radio: radio
        True/False: true_false
        Page Link: page_link
        Post Object: post_object
        Relationship: relationship
        Taxonomy: taxonomy
        User: user
        Google Map: google_map
        Date Picker: date_picker
        Color Picker: color_picker
        Group: group
        Repeater: repeater
        Flexible Content: flexible_content
        Gallery: gallery

    */

    switch ($type) {
      case 'text':
        return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" />';
        break;
      case 'number':
        return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" />';
        break;
      case 'email':
        return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" />';
        break;
      case 'url':
        return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" />';
        break;
      case 'radio':
        return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" />';
        break;
      case 'select':
        return '<select name="' . $field['name'] . '" id="' . $field['name'] . '">
           
              </select>';
        break;
    }
    ;

  }

}


add_action('init', function () {
  $cf = new cf7_ex();
  //$cf->build_tags();
  //  'build_tags'

});



add_filter('wpcf7_editor_panels', function ($panels) {
  $panels['preview-panel'] = array(
    'title' => __('Save to Lead', 'contact-form-7'),
    'callback' => 'leadgen_wpcf7_editor_panel_api',
  );
  return $panels;
}, 10, 1);
/**
 * Displays the APIs Fields panel in the Contact Form 7 editor.
 *
 * @param WP_Post $post The post object.
 */
function leadgen_wpcf7_editor_panel_api($post)
{
  ?>
  <h2>
    <?php echo esc_html(__('APIs Fields', 'contact-form-7')); ?>
  </h2>
  <fieldset>
    <label for="wpcf7-leadgen-on">SAVE ON</label>
    <input value="on" type="checkbox" id="wpcf7-leadgen-on" name="leadgen-on" <?php if (get_post_meta($post->id(), 'leadgen-on', true) == 'on') { ?>checked="checked" <?php } ?> />
    <br>
  </fieldset>
  <fieldset>
    <label for="wpcf7-leadgen-on">Accept Job Formular</label>
    <input value="on" type="checkbox" id="wpcf7-leadgen-accept-post" name="leadgen-accept-post" <?php if (get_post_meta($post->id(), 'leadgen-accept-post', true) == 'on') { ?>checked="checked" <?php } ?> />
    <br>
  </fieldset>
  <fieldset>
    <label for="wpcf7-leadgen-on">Company Form</label>
    <input value="on" type="checkbox" id="wpcf7-leadgen-company_form" name="leadgen-company_form" <?php if (get_post_meta($post->id(), 'leadgen-company_form', true) == 'on') { ?>checked="checked" <?php } ?> />
    <br>
  </fieldset>
<?php }
/**
 * Saves custom fields for a post in the wpcf7 plugin.
 *
 * @param int $post_id The ID of the post to save custom fields for.
 * @return void
 */
function save_wpcf7_custom_fields($post_id)
{

  if (array_key_exists('leadgen-on', $_POST)) {

    update_post_meta($post_id, 'leadgen-on', $_POST['leadgen-on']);
  } else {
    update_post_meta($post_id, 'leadgen-on', '');
  }
  if (array_key_exists('leadgen-accept-post', $_POST)) {
    update_post_meta($post_id, 'leadgen-accept-post', $_POST['leadgen-accept-post']);
  } else {
    update_post_meta($post_id, 'leadgen-accept-post', '');
  }
  if (array_key_exists('leadgen-company_form', $_POST)) {
    update_post_meta($post_id, 'leadgen-company_form', $_POST['leadgen-company_form']);
  } else {
    update_post_meta($post_id, 'leadgen-company_form', '');
  }

}

add_action('save_post', 'save_wpcf7_custom_fields');


add_action('wpcf7_init', 'custom_add_form_tag_clock');
/**
 * Adds custom form tags for clock, post, product, order, and external mail.
 *
 * @since 1.0.0
 * @return void
 */
function custom_add_form_tag_clock()
{
  wpcf7_add_form_tag(
    ['acf', 'acf*', 'acf *'],
    'custom_clock_form_tag_handler',
    array(
      'name-attr' => true,
      'autocomplete' => true,
      'class' => true
    )
  );

  wpcf7_add_form_tag(
    ['post', 'post*', 'post *'],
    'custom_post_form_tag_handler',
    array(
      'name-attr' => true,
      'autocomplete' => true,
      'class' => true
    )
  );
  wpcf7_add_form_tag(
    ['product', 'product*', 'product *', 'product_lead'],
    'custom_post_woocommerce_product_tag_handler',
    array(
      'name-attr' => true,
      'autocomplete' => true,
      'class' => true
    )
  );
  wpcf7_add_form_tag(
    ['order', 'order*', 'order *'],
    'custom_post_woocommerce_order_tag_handler',
    array(
      'name-attr' => true,
      'autocomplete' => true,
      'class' => true
    )
  );

  wpcf7_add_form_tag(
    ['external_mail'],
    'external_mail_tag_handler'

  );
}
/**
 * Retrieves the external mail tag for the current post.
 *
 * @return string The HTML input tag for the external mail value, if it exists.
 */
function external_mail_tag_handler()
{
  global $post;
  $job_detail_mail = get_post_meta($post->ID, 'job_detail_mail', true);

  if ($job_detail_mail) {
    return '<input type="hidden" name="external_mail" value="' . $job_detail_mail . '" />';
  }
}
/**
 * Replaces all instances of 'd' with ' Tage' in a given string.
 *
 * @param string $value The string to be modified.
 * @return string The modified string with 'd' replaced by ' Tage'.
 */
function replaces_d($value)
{
  return str_replace('d', ' Tage', $value);
}
/**
 * Retrieves and displays the specifications of a product.
 *
 * @param int $product_id The ID of the product to retrieve specifications for.
 * @return string The specifications of the product, including the duration of the advertisement and whether it is a premium listing.
 */
function show_product_specifications($product_id)
{

  $premium = get_field('premium', $product_id);
  $delete_period = get_field('delete_period', $product_id);
  $refresh_period = get_field('refresh_period', $product_id);
  if ($premium == 1) {
    $premium = 'Premium';
  } else {
    $premium = '';
  }
  return ' Dauer der Anzeige: ' . replaces_d($delete_period) . ' ' . $premium;

}
/**
 * Retrieves a list of WooCommerce products and displays them in a form.
 *
 * @param $tag The tag to be used for filtering the products.
 * @return string The HTML code for the form.
 */
function custom_post_woocommerce_product_tag_handler($tag)
{


  // Query WooCommerce products in the category
  $args = [
    'posts_per_page' => -1,
    'post_type' => 'product',
    'post_status' => 'publish',
    'orderby' => 'menu_order',
    'order' => 'asc'
  ];
  $required = $tag->get_option('required', False);

  $products = new WP_Query($args);
  $form_products = [];
  foreach ($products->posts as $product) {
    $wc_product = wc_get_product($product->ID);

    $form_products[] = [
      "ID" => $product->ID,
      "price_html" => wc_price($wc_product->get_price()),
      'specifications' => show_product_specifications($product->ID),
      "title" => get_the_title($product->ID),
      'tag' => $tag,
      'required' => $required ? $required[0] : ''
    ];
  }

  // $output = '<select name="product[]' . $tag['name'] . '">';

  $template = apply_filters('wp_leadgen_template_path', 'form/products.twig');

  $data = [
    'products' => $form_products
  ];
  return Timber::compile($template, $data);


}

add_filter('wpcf7_validate_product', 'custom_product_validation_filter', 10, 2);

// Custom Validation for checkboxes
/**
 * Validates a custom product field in a form submission.
 *
 * @param $result The validation result object.
 * @param $tag The shortcode tag object.
 * @return The updated validation result object.
 */
function custom_product_validation_filter($result, $tag)
{
  $tag = new WPCF7_Shortcode($tag);

  $name = $tag->name;

  $required = $tag->get_option('required', '')[0];

  $value = isset($_POST['product']);


  if ($required && '' == $value) {
    $result->invalidate($tag, 'Dies ist ein Pflichtfeld. Bitte wählen Sie einen Anzeigentyp aus.');
  }


  return $result;
}


// Validation function
add_filter('wpcf7_validate_post_taxonomy', 'validate_post_taxonomy_validation_filter', 10, 2);
/**
 * Validates the post taxonomy validation filter.
 *
 * @param object $result The result object.
 * @param object $tag The tag object.
 * @return object The result object.
 */
function validate_post_taxonomy_validation_filter($result, $tag)
{
  $tag = new WPCF7_FormTag($tag);

  $name = $tag->name;
  $name = $name . '_terms';
  $required = $tag->get_option('required', '')[0];

  $value = isset($_POST[$name]) ? trim(wp_unslash(strtr((string) $_POST[$name], "\n", " "))) : '';

  if ($required && '' == $value) {
    $result->invalidate($tag, 'Dies ist ein Pflichtfeld. Bitte wählen Sie mindestens ein Feld aus.');
  }

  // Add your custom validation rules here

  return $result;
}
/**
 * Handles the creation of a custom post taxonomy form tag.
 *
 * @param array $tag The form tag to be processed.
 * @return string The compiled template with the necessary data.
 */
function custom_post_taxonomy_form_tag_handler($tag)
{

  $tag = new WPCF7_FormTag($tag);
  $title = $tag->get_option('title', '');
  $id = $tag->get_option('id', '');
  $required = $tag->get_option('required', False);


  $terms = get_terms(
    array(
      'taxonomy' => $tag['name'],
      'hide_empty' => false,
    )
  );


  $template = apply_filters('wp_leadgen_template_path', '/form/terms.twig');


  $data = [
    'terms' => $terms,
    'id' => $id[0],
    'tag' => $tag,
    'title' => $title[0],
    'required' => $required[0],
    'value' => []
  ];


  return Timber::compile($template, $data);

}
/**
 * Handles the custom clock form tag by retrieving the field with the given name and passing it to the switch_types function.
 *
 * @param array $tag The tag array containing the name of the field.
 * @return mixed The result of the switch_types function.
 */
function custom_clock_form_tag_handler($tag)
{

  $name = $tag['name'];
  $field = acf_get_field($name);
  return switch_types($field, $tag);
}
/**
 * Handles the custom post form tag by passing it to the switch_post_fields function.
 * 
 * @param string $tag The tag to be handled.
 * @return string The result of the switch_post_fields function.
 */
function custom_post_form_tag_handler($tag)
{


  return switch_post_fields($tag);
}
/**
 * Checks if a field is required and returns the 'required' attribute if it is.
 *
 * @param array $field The field to be checked.
 * @return string The 'required' attribute if the field is required, otherwise an empty string.
 */
function required($field)
{
  if ($field['required'] == 1) {
    return 'required';
  } else {
    return '';
  }
}
/**
 * Returns the HTML code for a specific type of form field.
 *
 * @param array $field The field to generate HTML for.
 * @param object $tag The tag object.
 * @return string The HTML code for the field.
 */
function switch_types($field, $tag)
{
  $class = $tag->get_class_option();
  $autocomplete = $tag->get_option('autocomplete', 'on');

  $required = required($field);
  $atts = array();
  $atts['name'] = $tag->name;
  $atts = wpcf7_format_atts($atts);

  switch ($field['type']) {


    case 'text':
      return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" class="' . $class . '" autocomplete="' . $autocomplete . '" placeholder="' . $placeholder . '" ' . $required . '/>';
      break;
    case 'number':
      return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" class="' . $class . '" autocomplete="' . $autocomplete . '" placeholder="' . $placeholder . '" ' . $required . '/>';
      break;
    case 'email':
      return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" class="' . $class . '" autocomplete="' . $autocomplete . '" placeholder="' . $placeholder . '" ' . $required . '/>';
      break;
    case 'url':
      return '<input type="' . $field['type'] . '" name="' . $field['name'] . '" value="" class="' . $class . '" autocomplete="' . $autocomplete . '" placeholder="' . $placeholder . '" ' . $required . '/>';
      break;

    case 'radio':
      $html = '';
      foreach ($field['choices'] as $k => $choice) {

        $html .= '<input id="' . $field['name'] . '_' . $k . '" type="' . $field['type'] . '" name="' . $field['name'] . '" value="' . $k . '" ' . $required . '/>';
        $html .= '<label for="' . $field['name'] . '_' . $k . '">' . $choice . '</label>';
      }

      return $html;


      break;

    case 'select':

      $html = '';
      $html .= '<select name="' . $field['name'] . '" id="' . $field['name'] . '" class="' . $class . '" autocomplete="' . $autocomplete . '" ' . $required . '>';
      foreach ($field['choices'] as $k => $choice) {
        $html .= ' <option value="' . $k . '">' . $choice . '</option>';

      }
      $html .= '</select>';
      return $html;
      break;
    case 'date_picker':
      return '<input type="date" name="' . $field['name'] . '" value=""  class="' . $class . '" autocomplete="' . $autocomplete . '" ' . $required . '/>';
      break;
  }
}
;
/**
 * Switches between different post fields based on the given tag.
 *
 * @param $tag The tag to be used for determining the post field.
 * @return string The HTML code for the corresponding post field.
 */
function switch_post_fields($tag)
{
  $class = $tag->get_class_option();
  $autocomplete = $tag->get_option('autocomplete', 'on');


  $atts = array();
  $atts['name'] = $tag->name;
  $atts = wpcf7_format_atts($atts);

  switch ($tag['name']) {


    case 'post_title':
      return '<input type="text" name="post[post_title]" value="" class="' . $class . '" autocomplete="' . $autocomplete . '" placeholder="' . $placeholder . '" ' . $required . '/>';
      break;
    case 'post_content':
      return '<textarea name="post[post_content]" rows="4" cols="50">Job Beschreibung</textarea>';
      break;
  }


}





add_filter('wpcf7_validate_auto_geo_field', 'custom_auto_geo_field_validation', 10, 2);
/**
 * Validates the auto_geo_field form tag.
 *
 * @param WPCF7_ValidationResult $result The validation result object.
 * @param WPCF7_FormTag $tag The form tag object.
 * @return WPCF7_ValidationResult The updated validation result object.
 */
function custom_auto_geo_field_validation($result, $tag)
{
  $tag = new WPCF7_FormTag($tag);

  if ($tag->name == 'auto_geo_field') {
    $fieldsToValidate = ['adress'];

    foreach ($fieldsToValidate as $field) {
      $value = isset($_POST[$field]) ? trim($_POST[$field]) : '';

      if (empty($value)) {
        $result->invalidate($tag, 'Dies ist ein Pflichtfeld.');
      }
    }
  }
  return $result;
}




/*
add_filter('wpcf7_form_tag', 'your_custom_wpcf7_form_tag_filter', 10, 2);
/**
* Filters the form tag for a Contact Form 7 form.
 *
 * @param array $tag The form tag to be filtered.
 * @param bool $unused Unused parameter.
 * @return array The filtered form tag.
*/
function your_custom_wpcf7_form_tag_filter($tag, $unused)
{

  if ($unused == true)
    $values = get_field($tag['name']);

  if (isset($values)) {
    foreach ($values as $value) {
      if ($tag['name'] == $value['value']) {
        $tag['values'] = (array) $value['value'];
      }
    }
  }
  return $tag;
}


add_filter( 'wpcf7_form_tag', 'customize_cf7_form_tag', 10, 2 );
function customize_cf7_form_tag( $tag, $unused ) {

    if ( $tag['type'] == 'file' && in_array( 'class:previewImages', $tag['options'] ) ) {



        $tag['values'][] = 'imagePreview';
        $tag['content'] =   $tag['content']. '<img src="" id="imagePreview"/>'.
                        '<div id="cropBoxData"/>'.
                        '<div id="button">Button</div><div id="result"></div>';

    }
    return $tag;
}

add_filter('wpcf7_form_tag', 'customize_cf7_form_tag2', 10, 2);

function customize_cf7_form_tag2($tag, $unused) {
    if ($tag['type'] == 'file' && in_array('class:previewImages', $tag['options'])) {
        $html_content = '<img src="" id="imagePreview"/> <div id="cropBoxData"></div> <div id="button">Button</div> <div id="result"></div>';
   
        // Append the HTML content to the label part of the tag
        $tag['raw_values'] = $tag['content'] . $html_content;
        
        // Update the tag type and set it as HTML
        $tag['type'] = 'html';
    }
    return $tag;
}