<?php
/**
 * Class Custom_Admin_View
 * @package LeadGenerator
 *
 * @since 0.2.1
 */
function load_wp_tiny_mce()
{
    wp_enqueue_editor();
}
add_action('admin_enqueue_scripts', 'load_wp_tiny_mce');
class Custom_Admin_View
{
    /**
     * Constructor for the class.
     *
     * This method initializes the class and adds necessary actions for the plugin to function properly in the WordPress admin area.
     *
     * @since 1.0.0
     */
    public function __construct()
    {
        add_action('admin_enqueue_scripts', array($this, 'enqueue_styles'));
        add_action('admin_enqueue_scripts', array($this, 'enqueue_scripts'));
        add_action('add_meta_boxes', array($this, 'add_custom_meta_box'));
        add_action('do_meta_boxes', array($this, 'disable_plugin_meta_boxes'));
        add_action('admin_menu', array($this, 'add_admin_page'));

    }
    /**
     * Enqueues custom admin styles for the current theme.
     *
     * @since 1.0.0
     */
    public function enqueue_styles()
    {
        wp_enqueue_style('custom-admin-styles', get_stylesheet_directory_uri() . '/custom-admin-view.css');
    }
    /**
     * Enqueues custom admin scripts for the current theme.
     *
     * @since 1.0
     */
    public function enqueue_scripts()
    {
        wp_enqueue_script('custom-admin-scripts', get_template_directory_uri() . '/custom-admin-view.js', array('jquery'), '1.0', true);
    }
    /**
     * Returns the number of published jobs.
     *
     * @return int The number of published jobs.
     */
    public function get_published_jobs_count()
    {
        $args = array(
            'post_type' => 'job',
            'post_status' => 'publish',
        );
        $query = new WP_Query($args);

        return $query->found_posts;
    }
    /**
     * Retrieves the number of jobs to be deleted from the database.
     * 
     * @return int The number of jobs to be deleted.
     */
    public function get_to_delete_jobs_count()
    {
        $query = new LGenQuery();
        $query->get_all_jobs_to_delete();
        // return $query->found_posts;
    }
    /**
     * Returns the number of jobs that are in the "pre-pending" status and ready to be published.
     *
     * @return int The number of jobs in the "pre-pending" status.
     */
    public function get_to_publish_jobs_count()
    {
        $args = array(
            'post_type' => 'job',
            'post_status' => 'pre-pending',
        );
        $query = new WP_Query($args);

        return $query->found_posts;
    }
    /**
     * Adds custom meta boxes for the 'job' post type.
     *
     * @return void
     */
    public function add_custom_meta_box()
    {
        $user = wp_get_current_user();
        //  add_meta_box('custom_job_meta_box', 'Job Anzeige Informationen', array($this, 'custom_meta_box_callback'), 'job', 'normal', 'high');
        add_meta_box('custom_action_box', 'Anzeige', array($this, 'custom_action_box_callback'), 'job', 'normal', 'high');
        add_meta_box('custom_meta_box', 'Anzeige Addresse und Geo Daten', array($this, 'geo_address_box'), 'job', 'normal', 'high');


    }
    /**
     * Callback function for custom action box.
     *
     * @return void
     */
    public function custom_action_box_callback()
    {
        global $post;
        $product_id = get_post_meta($post->ID, 'product_id', true);
        Class_woocommerce_Helper::select_product($post->ID, $product_id);
        Class_woocommerce_Helper::show_product_info($product_id);
        Class_woocommerce_Helper::show_calendar_info($post->ID);
        Class_woocommerce_Helper::show_order_info($product_id);
        ?>


        <button>Bestellung erstellen</button>
        <button>Rechnung erstellen</button>

        <?php
    }
    /**
     * Renders a field with a label and input element.
     *
     * @param string $key The key for the field.
     * @param string $value The value for the field.
     * @return string The rendered field with a label and input element.
     */
    private function render_field($key, $value)
    {
        return '<label for="' . $key . '" >' . $key . '<input type="text" value="' . $value . '" name="' . $key . '" /></label></br>';
    }
    /**
     * Displays the admin page for the custom lead generation plugin.
     *
     * @return void
     */
    public function display_admin_page()
    {
        $active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'accounts';

        ?>
        <h2 class="nav-tab-wrapper">

            <a href="?page=custom-admin-page&tab=accounts"
                class="nav-tab <?php echo $active_tab == 'accounts' ? 'nav-tab-active' : ''; ?>">Accounts</a>
            <a href="?page=custom-admin-page&tab=jobs"
                class="nav-tab <?php echo $active_tab == 'jobs' ? 'nav-tab-active' : ''; ?>">Jobs</a>
            <a href="?page=custom-admin-page&tab=shortcodes"
                class="nav-tab <?php echo $active_tab == 'shortcodes' ? 'nav-tab-active' : ''; ?>">Shortcodes</a>
            <a href="?page=custom-admin-page&tab=settings"
                class="nav-tab <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>">Settings</a>
        </h2>

        <form method="post" action="options.php">
            <?php
            if ($active_tab == 'accounts') {
                settings_fields('custom-admin-page-accounts');
                do_settings_sections('custom-admin-page-accounts');
                submit_button();
            } elseif ($active_tab == 'jobs') {

                //   settings_fields('custom-admin-page-jobs');
                //   do_settings_sections('custom-admin-page-jobs');
                ?>

                <h3>JobAnzeigen</h3>
                <?php
                $site_url = site_url();
                ?>

                <h3>Anleitung für die Einrichtung eines Cron-Jobs in All-Inkl</h3>
                <div style="margin: 10px 0;">
                    <p>1. Melden Sie sich bei Ihrem All-Inkl KAS (Kundenadminserver) an.</p>
                    <p>2. Klicken Sie auf das Menü "Extras" und wählen Sie "Cronjobs".</p>
                    <p>3. Klicken Sie auf "Neuen Cronjob anlegen".</p>
                    <p>4. Unter "Befehl", geben Sie den Pfad zur PHP-Datei an, die gestartet werden soll. Ersetzen Sie dabei
                        "<?php echo $site_url; ?>" durch die tatsächliche URL Ihrer Website. Beispiel-Befehle könnten so aussehen:
                    </p>
                    <code><?php echo $site_url; ?>/?lg-job=refresh_jobs&lg-referer=true</code><br>
                    <code><?php echo $site_url; ?>/?lg-job=delete_jobs&lg-referer=true'</code>
                    <p>5. Definieren Sie, wann der Cron-Job ausgeführt werden soll. Richten Sie Ihn so ein, dass dieser jeden Tag um
                        00:00 Uhr läuft.</p>
                    <p>6. Klicken Sie auf "Speichern", um die Änderungen zu bestätigen.</p>

                </div>
                <p>Published Jobs: <?php echo $this->get_published_jobs_count(); ?></p>
                <p>To Delete Jobs: <?php echo $this->get_to_delete_jobs_count(); ?></p>


                <h3>Delete Jobs</h3>
                <!-- Add delete jobs button here -->
                <a href="?lg-job=delete_jobs&lg-referer=true" class="button button-primary">Delete Jobs</a>

                <h3>Refresh Jobs</h3>
                <!-- Add refresh jobs button here -->
                <a href="?lg-job=refresh_jobs&lg-referer=true" class="button button-primary">Refresh Jobs</a>

                <h3>Accept all Jobs</h3>
                <!-- Add refresh jobs button here -->
                <a href="?lg-job=accept_all_jobs&lg-referer=true" class="button button-primary">Accept all Jobs</a>

                <h3>Delete hanging Jobs</h3>
                <!-- Add refresh jobs button here -->
                <a href="?lg-job=delete_hanging_jobs&lg-referer=true" class="button button-primary">Delete hanging Jobs</a>


                <?php

            } elseif ($active_tab == 'shortcodes') {


                include(LGenPath . 'includes/shortcode_data.php');

                $shortcodesByClass = groupShortcodesByClass($shortcodes);
                $template = apply_filters('wp_leadgen_template_path', 'admin/shortcodes.twig');

                $data = [
                    'shortcodes' => $shortcodesByClass
                ];
                $rendered_html = Timber::compile($template, $data);
                echo $rendered_html;


                echo Timber::compile('admin/shortcodes.twig', $data);




            } elseif ($active_tab == 'settings') {

                settings_fields('setting_tab');
                do_settings_sections('setting_tab');
                submit_button();
            }
            ?>
        </form>
        <?php
    }
    /**
     * Displays the old version of the admin page.
     *
     * @return void
     */
    public function display_admin_page_old()
    {
        $active_tab = isset($_GET['tab']) ? $_GET['tab'] : 'accounts';

        ?>
        <h2 class="nav-tab-wrapper">

            <a href="?page=custom-admin-page&tab=accounts"
                class="nav-tab <?php echo $active_tab == 'accounts' ? 'nav-tab-active' : ''; ?>">Accounts</a>
            <a href="?page=custom-admin-page&tab=jobs"
                class="nav-tab <?php echo $active_tab == 'jobs' ? 'nav-tab-active' : ''; ?>">Jobs</a>
        </h2>

        <form method="post" action="options.php">
            <?php
            if ($active_tab == 'accounts') {
                settings_fields('custom-admin-page-accounts');
                ?>             <?php
                             do_settings_sections('custom-admin-page-accounts');
            } elseif ($active_tab == 'jobs') {
                ?>

                <h3>Delete Jobs</h3>

                <h3>Job Static</h3>
                <?php

                settings_fields('custom-admin-page-jobs');
                do_settings_sections('custom-admin-page-jobs');
            }
            submit_button();
            ?>
        </form>
        <?php
    }
    /**
     * Adds a custom admin page for the WP LeadGen Generator plugin.
     *
     * @return void
     */
    public function add_admin_page()
    {
        add_menu_page(
            'WP LeadGen Generator', // page title
            'LeadGen Dashboard', // menu title
            'edit_posts', // capability
            'custom-admin-page', // menu slug
            array($this, 'display_admin_page'), // function
            'dashicons-admin-generic', // icon URL
            30 // menu position
        );

        add_settings_section('accounts_tab', 'Accounts', '', 'custom-admin-page-accounts');
        add_settings_section('jobs_tab', 'Jobs', '', 'custom-admin-page-jobs');
        add_settings_section('setting_tab', 'Settings', '', 'setting_tab');

        // Add the setting field to the specific menu_slug ('setting_tab')
        add_settings_field(
            'admin_mails', // ID of field
            'Admin Mails', // Title of field
            [$this, 'display_admin_mails'], // Callback function
            'setting_tab', // Page on which to display this field
            'setting_tab' // Section to which this field belongs
        );
        add_settings_field(
            'leadgen_filter_text', // ID of field
            'Filter Text', // Title of field
            [$this, 'display_leadgen_filter_text'], // Callback function
            'setting_tab', // Page on which to display this field
            'setting_tab' // Section to which this field belongs
        );

        add_settings_field(
            'leadgen_email_footer_text', // ID of field
            'Email Footer Text', // Title of field
            [$this, 'display_leadgen_email_footer_text'], // Callback function
            'setting_tab', // Page on which to display this field
            'setting_tab' // Section to which this field belongs
        );
        add_settings_field(
            'leadgen_job_new_days', // ID of field
            'Number of Days who Jobs are new', // Title of field
            [$this, 'display_leadgen_job_new_days'], // Callback function
            'setting_tab', // Page on which to display this field
            'setting_tab' // Section to which this field belongs
        );

        add_settings_field(
            'leadgen_cf7_company_registration_form_id', // ID of field
            'Formular for Company Registration', // Title of field
            [$this, 'leadgen_cf7_company_registration_form_id'], // Callback function
            'setting_tab', // Page on which to display this field
            'setting_tab' // Section to which this field belongs
        );

        add_settings_field(
            'leadgen_google_api_key', // ID of field
            'Google API Key', // Title of field
            [$this, 'google_api_key_form'], // Callback function
            'setting_tab', // Page on which to display this field
            'setting_tab' // Section to which this field belongs
        );

        // Register the setting to avoid "Option page not found" issues
        register_setting('setting_tab', 'admin_mails');
        register_setting('setting_tab', 'leadgen_google_api_key');
        register_setting('setting_tab', 'leadgen_filter_text');
        register_setting('setting_tab', 'leadgen_email_footer_text');
        register_setting('setting_tab', 'leadgen_job_new_days');
        register_setting('setting_tab', 'leadgen_cf7_company_registration_form_id');
    }

    public function google_api_key_form()
    {
        $leadgen_google_api_key = get_option('leadgen_google_api_key');
        echo '<input type="text" name="leadgen_google_api_key" value="' . esc_attr($leadgen_google_api_key) . '"/>';
    }


    /**
     * Displays the input field for the "leadgen_job_new_days" option, which determines the number of days a job listing will be considered "new" on the website.
     *
     * @return void
     */
    public function display_leadgen_job_new_days()
    {
        // get_option to fetch the field value from the database
        $leadgen_job_new_days = get_option('leadgen_job_new_days');
        echo '<input type="number" name="leadgen_job_new_days" value="' . esc_attr($leadgen_job_new_days) . '"/>';
    }
    /**
     * Retrieves the selected CF7 form ID for company registration from the database and populates a select dropdown with all available CF7 forms.
     *
     * @return void
     */
    public function leadgen_cf7_company_registration_form_id()
    {
        // An array to hold CF7 forms
        $cf7_forms = array();

        // Fetch CF7 forms from the database
        $args = array('post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1);
        $cf7_form_array = get_posts($args);

        // Fill the array with form IDs and titles
        foreach ($cf7_form_array as $form) {
            $cf7_forms[$form->ID] = $form->post_title;
        }

        // get_option to fetch the selected form ID from db
        $leadgen_selected_form = get_option('leadgen_cf7_company_registration_form_id');

        // Begin the select dropdown
        echo '<select name="leadgen_cf7_company_registration_form_id">';

        // Populate the dropdown with CF7 forms
        foreach ($cf7_forms as $id => $title) {
            echo '<option value="' . $id . '"' . selected($leadgen_selected_form, $id, false) . '>' . $title . '</option>';
        }

        // End the select dropdown
        echo '</select>';
    }
    /**
     * Displays the admin emails field in the settings page.
     *
     * Retrieves the admin emails field value from the database using the get_option function and displays it as a text input field.
     *
     * @return void
     */
    public function display_admin_mails()
    {
        // get_option to fetch the field value from the database
        $admin_mails = get_option('admin_mails');
        echo '<input type="text" name="admin_mails" value="' . esc_attr($admin_mails) . '"/>';
    }
    /**
     * Displays the lead generation filter text in a WordPress editor.
     * 
     * @return void
     */
    public function display_leadgen_filter_text()
    {
        $leadgen_filter_text = get_option('leadgen_filter_text');
        wp_editor(esc_attr($leadgen_filter_text), 'leadgen_filter_text', $settings = array());
    }
    /**
     * Displays the lead generation email footer text.
     *
     * Retrieves the lead generation email footer text from the database and displays it in a WordPress editor.
     *
     * @return void
     */
    public function display_leadgen_email_footer_text()
    {
        $leadgen_email_footer_text = get_option('leadgen_email_footer_text');
        wp_editor(esc_attr($leadgen_email_footer_text), 'leadgen_email_footer_text', $settings = array());
    }
    /**
     * Displays a box for entering and updating geographic address data.
     * 
     * @global WP_Post $post The current post object.
     * @return void
     */
    public function geo_address_box()
    {
        global $post;
        $meta_data = get_post_meta($post->ID);


        ?>
        <div class="flex-wrapper" style="display:inline-grid; width:100%;grid-template-columns: 1fr 1fr;">
            <div>

                <?php
                echo $this->render_field('longitude', $meta_data['longitude'][0]);
                echo $this->render_field('latitude', $meta_data['latitude'][0]);
                echo $this->render_field('country', $meta_data['country'][0]);
                echo $this->render_field('street', $meta_data['street'][0]);
                echo $this->render_field('city', $meta_data['city'][0]);
                echo $this->render_field('zip', $meta_data['zip'][0]);

                echo '<div style="margin-top:5px;">';
                echo '<input type="button" value="Update GeoDaten" id="my_custom_button" class="button" style="width:100%;" />';
                echo '<input type="button" value="get Adress from GPS" id="get_address_from_gps" class="button" style="width:100%;" />';
                echo '</div>';


                ?>

            </div>
            <div>
                <?php echo do_shortcode('[single_map]'); ?>
            </div>


        </div>

        <?php

    }
    /**
     * Renders a custom meta box for the current post.
     *
     * @param none
     * @return void
     */
    public function custom_meta_box_callback()
    {
        global $post;
        $meta_data = get_post_meta($post->ID);


        $filter_regex = '/^customer_/'; // Regex filter for fields starting with 'leadgen_'

        echo '<table>';
        foreach ($meta_data as $key => $value) {
            if (preg_match($filter_regex, $key)) {
                echo '<tr>';
                echo '<td>' . $this->render_field($key, $value[0]) . '</td>';
                echo '</tr>';
            }
        }
        echo '</table>';
        ?>


        <?php


    }
    /**
     * Disables specific plugin meta boxes for users with the 'um_jobmitarbeiter' role.
     *
     * @return void
     */
    public function disable_plugin_meta_boxes()
    {
        $user = wp_get_current_user();
        if (in_array('um_jobmitarbeiter', $user->roles)) {
            remove_meta_box('rank_math_seo', 'job', 'normal');
            // Add more plugin meta boxes to disable if needed
        }
    }
}
new Custom_Admin_View();
/**
 * Adds a custom user role with the capabilities of editing and deleting posts, as well as editing jobs.
 *
 * @param string $role_name The name of the custom user role.
 * @param string $display_name The display name of the custom user role.
 * @param array $capabilities Additional capabilities to be assigned to the custom user role.
 * @return void
 */
function add_custom_user_role()
{
    add_role(
        'ma',
        'JobManager',
        array(

            'edit_posts' => true,
            'delete_posts' => true,
            'edit_job' => true,
            // Add more capabilities as required for the role
        )
    );


}
add_action('init', 'add_custom_user_role');
/**
 * Removes custom post type capabilities from the 'um_jobmitarbeiter' role.
 * 
 * @return void
 */
function remove_cpt_capability()
{
    // get the editor role
    $role = get_role('um_jobmitarbeiter');
    // check if the role exists
    if (!is_null($role)) {
        // remove capability to the role
        $role->remove_cap('edit_companies');
        $role->remove_cap('read_companies');
        $role->remove_cap('delete_companies');
        // remove capability to the role
        $role->remove_cap('edit_company');
        $role->remove_cap('read_company');
        $role->remove_cap('delete_company');
    }
}
add_action('init', 'remove_cpt_capability');
/**
 * Modifies the admin sidebar based on the current user's role.
 *
 * @return void
 */
function modify_admin_sidebar()
{
    $user = wp_get_current_user();

    new Custom_Admin_View();
    if (in_array('um_jobmitarbeiter', $user->roles)) {
        remove_menu_page('edit.php'); // Remove Posts
        remove_menu_page('wpcf7'); // Remove Contact Form 7
        remove_menu_page('edit-comments.php'); // Remove Comments
        remove_menu_page('profile.php'); // Remove Profile
        remove_menu_page('tools.php'); // Remove Tools
        remove_menu_page('index.php');
        remove_menu_page('edit.php?post_type=company');
    }
}
add_action('admin_menu', 'modify_admin_sidebar', 999);

add_action('init', 'disable_wc_um_view_for_role');
/**
 * Disables the view for the specified role in WooCommerce.
 *
 * @param void
 * @return void
 */
function disable_wc_um_view_for_role()
{
    if (current_user_can('um_jobmitarbeiter')) {
        // For WooCommerce
        remove_action('woocommerce_account_content', 'woocommerce_account_content');
        // For automatic redirect

    }
}



use Lightweb_Media\Lightweb_Media_Admin_Pages\LWM_Admin_Pages;
use Lightweb_Media\Lightweb_Media_Admin_Pages\LWM_Admin_Forms;
use Lightweb_Media\Lightweb_Media_License\LWM_License;

add_action('init', function () {

    if (is_admin()) {
        $options = get_option('LeadGenerator');


        $plugin_slug = plugin_basename(LGenPath);

        $license = new LWM_License(
            LGenPath . '/leadgenerator.php',
            'wp_leadgenerator',
            $plugin_slug,
            $options['license_key'] ?? ''
        );

        $lic = false;
        // $lic = $license->init();

        $options_page_1 = new LWM_Admin_Forms(
            'license_key',
            [
                [
                    'id' => 'license_key',
                    'title' => __('License Key', 'leadgenerator'),
                    'description' => __('Enter your license key here.', 'leadgenerator'),
                ]
            ]
        );

        $admin_page = new LWM_Admin_Pages(
            $plugin_slug,
            __('LeadGenerator', 'leadgenerator'),
            __('LeadGenerator', 'leadgenerator'),
            'manage_options',
            function () use ($options_page_1) {
                echo '<h1>LeadGenerator</h1>';

                $options_page_1->render_options_page();
            }
        );
    }

});

