<?php
/**
 * Class Class_calendar
 * @package LeadGenerator
 *
 * @since 0.2.1
 */
class Class_calendar
{
    /**
     * Constructor method for the class.
     * Adds a filter to the query variables, using the job_params method of the current object.
     *
     * @return void
     */
    function __construct()
    {
        add_filter('query_vars', [$this, 'job_params']);
    }
    /**
     * Adds 'lg-job' and 'lg-referer' parameters to the given array.
     *
     * @param array $qvars The array to add parameters to.
     * @return array The updated array with added parameters.
     */
    function job_params($qvars)
    {
        $qvars[] = 'lg-job';
        $qvars[] = 'lg-referer';
        return $qvars;
    }
    /**
     * Checks the job type and performs the corresponding action.
     *
     * @param string $job_type The type of job to be checked.
     * @return void
     */
    function check_job_task($job_type)
    {
        if (
            !in_array($job_type, [
                'delete_jobs',
                'refresh_jobs',
                'delete_hanging_jobs',
                'accept_all_jobs'
            ])
        ) {
            return;
        }
        if ($job_type === 'delete_jobs') {

            $query = new LGenQuery();
            $query->delete_all_jobs();
        }
        if ($job_type === 'refresh_jobs') {
            $query = new LGenQuery();
            $query->refresh_jobs();
        }
        if ($job_type === 'accept_all_jobs') {
            $query = new LGenQuery();
            $query->accept_all_jobs();
        }
        if ($job_type === 'delete_hanging_jobs') {
            $query = new LGenQuery();
            $query->delete_all_unconfirmed_jobs();
        }
    }



}

add_action('init', 'check_job');
/**
 * Checks the job type and redirects the user back to the jobs tab after action.
 *
 * @param none
 * @return void
 */
function check_job()
{
    if (isset($_GET['lg-job']) && $_GET['lg-job']) {
        $job_type = $_GET['lg-job'];
        $calc_obj = new Class_calendar();
        $calc_obj->check_job_task($job_type);
        if (isset($_GET['lg-referer']) && $_GET['lg-referer']) {

            // redirect user back to jobs tab after action
            wp_redirect(admin_url('admin.php?page=custom-admin-page&tab=jobs'));
            exit;
        }
    }

}



