<?php
/**
 * Class LGenPost
 * @package LeadGenerator
 *
 * @since 0.2.1
 */

class LGenPost
{

    public $ID;

    public $permalink;
    public $gender;

    public $distance;
    public $premium;
    public $label;
    public $image;
    public $job_deadline;
    public $job_district;
    public $order_id;
    public $product_id;
    public $job_type;
    public $jobcategory;

    public $title;

    public $street;
    public $city;
    public $zip;
    public $country;
    public $latitude;
    public $longitude;
    public $job_start_date;
    public $job_salery;
    public $start_date;
    public $company;
    public $excerpt;
    public $description;
    public $job_ad_deadline;
    public $job_working_time;

    public $job_form_of_employment;
    public $type;
    /**
     * Constructor for the class.
     *
     * This function sets up various actions to be performed on different post and order status transitions.
     *
     * @since 1.0.0
     */
    public function __construct()
    {

        //add_action('save_post_job', [$this, 'update_post_data'], 100, 3);
        //   add_action('publish_job', [$this, 'on_post_publish'], 10, 2);
        add_action('transition_post_status', [$this, 'run_on_all_job_status_transitions'], 99, 3);
        //   add_action('woocommerce_order_status_changed', [$this, 'so_status_completed'], 10, 3);
    }
    /**
     * Displays the contact box for a job post.
     *
     * @param WP_Post $post The post object.
     */
    public static function show_contact_box($post)
    {

        $contact_type = get_post_meta($post->ID, 'contact', true);

        if ($contact_type === 'Weiterleitung') {
            $job_detail_link = get_post_meta($post->ID, 'job_detail_link', true);
            ?><a href="<?php echo $job_detail_link; ?>" class="button btn">zur Ausschreibung</a>
            <?php
        } elseif ($contact_type === 'per Mail') {


            ?>
            <?php echo do_shortcode('[contact-form-7 title="Job Contact Formular"]'); ?>
            <!--
            <button class="uk-button" data-uk-modal="{target:'#mail_modal'}">eMail schreiben</button>
            <div>
                <div id="mail_modal" class="uk-modal">
                    <div class="uk-modal-dialog">
                        <a class="uk-modal-close uk-close"></a>
                      
                    </div>
                </div>

            </div>
        -->
            <?php
        }

    }
    /**
     * Runs on all job status transitions and updates post meta accordingly.
     * 
     * @param string $new_status The new status of the job post.
     * @param string $old_status The previous status of the job post.
     * @param object $post The job post object.
     */
    function run_on_all_job_status_transitions($new_status, $old_status, $post)
    {
        if ($post->post_type == 'job') {
            if ($new_status == 'publish') {


                $product_id = get_post_meta($post->ID, 'product_id', true);

                $delete_period = get_post_meta($product_id, 'delete_period', true);
                $delete_period = rtrim($delete_period, 'd');
                $refresh_period = get_post_meta($product_id, 'refresh_period', true);
                $refresh_period = rtrim($refresh_period, 'd');
                $current_date = date('Ymd');

                $refresh_date = new DateTime($current_date);

                $expiry_date = new DateTime($current_date);

                $expiry_date->modify(modifier: "+" . $delete_period . " days");
                $refresh_date->modify("+" . $refresh_period . " days");

                update_post_meta($post->ID, 'job_start_date', '');
      

                update_post_meta($post->ID, 'job_ad_deadline', '');
                update_post_meta($post->ID, 'job_ad_deadline', $expiry_date->format("Ymd"));
                update_post_meta($post->ID, 'delete_period', '');
                update_post_meta($post->ID, 'delete_period', $expiry_date->format("Ymd"));
      

                $LGenPost = new LGenPost();
                $job = $LGenPost->setup_job($post);


                if ($job->street && $job->city && $job->zip && $job->country) {
                    $data = Nominatim::geocode($job->build_address());

                    update_post_meta($post->ID, 'longitude', $data['lon']);
                    update_post_meta($post->ID, 'latitude', $data['lat']);
                }

            }



        }
    }
    /**
     * Sets up a job object with data from a given post.
     *
     * @param $post The post to retrieve data from.
     * @return $this The job object with data set.
     */
    public function setup_job($post)
    {
        $this->ID = $post->ID;
        setup_postdata($post);
        $this->permalink = get_the_permalink($post->ID);
        /* if (get_field('job_link', $post->ID)) {
             $this->permalink = get_field('job_link', $post->ID);
         }
         */
        $this->title = get_the_title($post->ID);
        $this->description = get_the_content($post->ID);
        $this->excerpt = get_the_excerpt($post);
        // $this->street = get_field('street', $post->ID);
        $this->street = get_post_meta($post->ID, 'street', true);
        //  $this->city = get_field('city', $post->ID);
        $this->city = get_post_meta($post->ID, 'city', true);
        //   $this->zip = get_field('zip', $post->ID);
        $this->zip = get_post_meta($post->ID, 'zip', true);
        //   $this->country = get_field('country', $post->ID);
        $this->country = get_post_meta($post->ID, 'country', true);
        $this->company = get_field('job_company', $post->ID);
        $this->job_start_date = get_the_date('d.m.Y', $post->ID);

        $this->start_date = get_the_date($post->ID);

        $this->gender = get_field('gender', $post->ID);

        $this->distance = get_field('distance', $post->ID);
        $this->latitude = get_field('latitude', $post->ID);
        $this->longitude = get_field('longitude', $post->ID);

        $this->job_deadline = get_field('job_ad_deadline', $post->ID);

        $this->jobcategory = get_the_terms($post, 'jobcategory');
        $this->job_type = get_the_terms($post, 'job_type');
        $this->job_district = get_the_terms($post, 'job_district');

        $this->job_form_of_employment = get_the_terms($post, 'job_form_of_employment');
        $this->job_working_time = get_the_terms($post, 'job_working_time');

        $this->order_id = $this->get_order_from_job($post->ID);
        $this->product_id = $this->get_product_from_job($post->ID);
        $this->premium = get_field('premium', $post->ID);

        $this->image = get_the_post_thumbnail_url($post->ID);

        $this->job_salery = get_field('job_salery', $post->ID);
        $leadgen_job_new_days = get_option('leadgen_job_new_days');

        $this->label = '';

        if ($this->check_date_range($this->job_start_date, $leadgen_job_new_days)) {
            $this->label = 'Neu';
        }


        return $this;
    }
    /**
     * Checks if the difference between the given start date and the current date is less than or equal to the specified number of days.
     *
     * @param string $start_date The start date in the format 'd.m.Y'.
     * @param int $leadgen_job_new_days The number of days to compare the difference to.
     * @return bool Returns true if the difference is less than or equal to the specified number of days, false otherwise.
     */
    private function check_date_range($start_date, $leadgen_job_new_days)
    {
       if (!$start_date) {
        return false;
       }
        $now = new DateTime();

        // Convert start_date to DateTime object
        $start_date = DateTime::createFromFormat('d.m.Y', $start_date);

        // Calculate the difference in days
        $diff = $now->diff($start_date)->days;

        // Check if the difference is greater than leadgen_job_new_days
        if ($diff <= $leadgen_job_new_days) {
            return true;
        } else {
            return false;
        }
    }
    /**
     * Retrieves the product type from the job's associated product.
     * 
     * @return string|bool The product type if it exists, or false if it does not.
     */
    private function get_product_type_from_job()
    {

        if (isset($this->product_id)) {
            return get_post_meta($this->product_id, 'premium', true);
        }

    }
    /**
     * Retrieves the product ID associated with the given job ID.
     *
     * @param int $id The job ID to search for.
     * @return int|null The product ID if found, null otherwise.
     */
    private function get_product_from_job($id)
    {

        $query = new WC_Order_Query(
            array(
                'limit' => 1,
                'orderby' => 'date',
                'order' => 'DESC',
                'meta_key' => '_job_id',
                'meta_value' => $id,
            )
        );
        $orders = $query->get_orders();

        foreach ($orders as $order) {
            $items = $order->get_items();
            foreach ($items as $item) {
                return $item->get_id();
            }
        }

    }
    /**
     * Retrieves the order ID associated with a given job ID.
     *
     * @param int $id The job ID to search for.
     * @return int|false The order ID if found, false if not.
     */
    private function get_order_from_job($id)
    {

        $query = new WC_Order_Query(
            array(
                'limit' => 1,
                'orderby' => 'date',
                'order' => 'DESC',
                'return' => 'ids',
                'meta_key' => '_job_id',
                'meta_value' => $id,
            )
        );
        $orders = $query->get_orders();

        foreach ($orders as $order_id) {
            return $order_id;
        }

    }
    /**
     * Builds and returns a formatted address string using the street, city, zip, and country properties of the current object.
     *
     * @return string The formatted address string.
     */
    public function build_address()
    {
        $address = [
            $this->street,
            $this->city,
            $this->zip,
            $this->country

        ];
        return implode(',', $address);

    }
    /**
     * on_post_publish
     *
     * This function is triggered when a post is published.
     *
     * @param int $ID The ID of the post being published.
     * @param WP_Post $post The post object being published.
     */
    public function on_post_publish($ID, $post)
    {

        $current_date = current_time('Ymd');

        //   $delete_date = date('Ymd', strtotime($current_date . ' +' . $delete_period . ' days'));
        //   $refresh_date = date('Ymd', strtotime($current_date . ' +' . $refresh_date . ' days'));





    }
    /**
     * Updates the post data for a given post ID.
     *
     * @param int $post_id The ID of the post to update.
     * @param array $post The post data to update.
     * @param bool $update Whether to update the post or not.
     */
    public function update_post_data($post_id, $post, $update)
    {



        $LGenPost = new LGenPost();

        $job = $LGenPost->setup_job($post);
        $data = Nominatim::geocode($job->build_address());
        $meta = get_post_meta($post_id);

        $longitude = $meta['longitude'];
        $latitude = $meta['latitude'];
        update_post_meta($post_id, 'longitude', $data['lon']);
        update_post_meta($post_id, 'latitude', $data['lat']);

        if ($job->street && $job->city && $job->zip && $job->country) {

            $data = Nominatim::geocode($job->build_address());
            $meta = get_post_meta($post_id);

            $longitude = $meta['longitude'];
            $latitude = $meta['latitude'];
            update_post_meta($post_id, 'longitude', $data['lon']);
            update_post_meta($post_id, 'latitude', $data['lat']);



        }

    }
    /**
     * Renders a job item using a specified template.
     *
     * @param object $job The job object to be rendered.
     * @param string $template The template file to be used for rendering. Default is 'job-item.twig'.
     * @return string The rendered HTML for the job item.
     */
    public function render_job_item($job, $template = 'job-item.twig')
    {
        $template = apply_filters('wp_leadgen_template_path', 'job-item.twig');

        $job_array = (array) $job;
        $rendered_html = Timber::compile($template, $job_array);
        return $rendered_html;
    }
    /**
     * Renders the 404 error page for a job.
     *
     * @param string $template The template to use for rendering the page. Defaults to 'job-404.twig'.
     * @return string The rendered HTML for the 404 error page.
     */
    public function render_job_404($template = 'job-404.twig')
    {
        $template = apply_filters('wp_leadgen_template_path', 'job-404.twig');
        $rendered_html = Timber::compile($template);
        return $rendered_html;
    }
    /**
     * Updates the job ad deadline when the status is transitioned to "completed".
     *
     * @param int $id The order ID.
     * @param string $status_transition_from The status the order is transitioning from.
     * @param string $status_transition_to The status the order is transitioning to.
     */
    public static function so_status_completed($id, $status_transition_from, $status_transition_to)
    {
        if ($status_transition_to == "completed") {

            $job_id = wc_get_order_item_meta($id, '_job_id', true);



            $order = wc_get_order($id);
            $line_items = $order->get_items();

            // Step 3: Retrieve the first line item
            $first_line_item = reset($line_items);

            // Step 4: Access the product details within the line item
            $product_id = $first_line_item->get_product_id();
            //  $delete_period = get_post_meta($product_id, 'delete_period', true);

            $current_date = date('Y-m-d'); // Get the current date
            $deadline = date('Y-m-d', strtotime($current_date . ' + ' . $delete_period . ' days'));

            // Assuming you have the $lead_id variable defined
            //   update_post_meta($job_id, 'job_ad_deadline', $deadline);


        }


    }

}

add_action('wp_ajax_update_custom_meta', 'update_custom_meta');
/**
 * Updates custom meta data for a post.
 *
 * @param int $post_id The ID of the post to update.
 * @return array The geocoded data for the post's address.
 */
function update_custom_meta()
{
    // check_ajax_referer('my_custom_nonce');

    $post_id = $_POST['post_id'];
    $post = get_post($post_id);
    $LGenPost = new LGenPost();

    $job = $LGenPost->setup_job($post);

    $data = Nominatim::geocode($job->build_address());


    update_field('latitude', $data['lat'], $post_id);

    return $data;
    die();
}

add_action('wp_ajax_get_address_from_gps', 'get_address_from_gps');
/**
 * Retrieves address information from GPS coordinates and updates post meta data.
 *
 * @param int $post_id The ID of the post to update.
 * @return void
 */
function get_address_from_gps()
{
    // check_ajax_referer('my_custom_nonce');

    $post_id = $_POST['post_id'];
    $post = get_post($post_id);
    $LGenPost = new LGenPost();

    $lat = get_post_meta($post_id, 'latitude', true);
    $lon = get_post_meta($post_id, 'longitude', true);

    $data = Nominatim::reverseGeocode($lat, $lon);
    if ($data['address']) {
        $data = $data['address'];
        update_post_meta($post_id, 'city', $data['town']);
        update_post_meta($post_id, 'street', $data['road']);
        update_post_meta($post_id, 'zip', $data['postcode']);
        update_post_meta($post_id, 'country', $data['country']);

    }


}

add_action('admin_footer', 'custom_button_js');
/**
 * This function adds custom JavaScript functionality to a custom button on the job post type.
 *
 * @return void
 */
function custom_button_js()
{
    global $post;
    if (!isset($post)) {
        return;
    }
    if ($post->post_type == 'job') { // replace 'your_cpt' with your custom post type
        echo "<script>
        jQuery(document).ready(function($) {
            $('#my_custom_button').click(function(){
   
                $.post(ajaxurl, {
                    action: 'update_custom_meta', 
                    post_id: " . $post->ID . ", 
     
                }, function(response) {

                    console.log(response);
					location.reload(); 
                });
            });
            $('#get_address_from_gps').click(function(){
   
         
                $.post(ajaxurl, {
                    action: 'get_address_from_gps', 
                    post_id: " . $post->ID . ", 
     
                }, function(response) {
                   location.reload(); 
                });
            });
        });
        </script>";
    }
}

new LGenPost();

