<?php
/**
 * Class OpenStreetMapPlugin
 * @package LeadGenerator
 *
 * @since 0.2.1
 */

defined('ABSPATH') || exit;
class OpenStreetMapPlugin
{
    private $geoPoints = array();
    /**
     * Constructor function for the OpenStreetMap plugin.
     *
     * Registers styles and scripts, as well as shortcodes for displaying maps.
     *
     * @since 1.0.0
     */
    function __construct()
    {
        // Register styles and scripts
        //  add_action('wp_enqueue_scripts', array($this, 'register_files'));
        //   add_action('admin_enqueue_scripts', array($this, 'register_files'));
        // Register shortcode
        add_shortcode('openstreetmap', array($this, 'map_shortcode'));
        add_shortcode('single_map', array($this, 'single_map'));
    }
    /**
     * Registers and enqueues necessary files for the Leaflet map functionality.
     *
     * @return void
     */
    public function register_files()
    {
        wp_register_style('leaflet_css', 'https://unpkg.com/leaflet/dist/leaflet.css');
        wp_register_script('leaflet_js', 'https://unpkg.com/leaflet@1.7.1/dist/leaflet.js', array(), null, true);
        wp_enqueue_style('leaflet_css');
        wp_enqueue_script('leaflet_js');

        // Localize PHP array to javascript
        wp_localize_script('leaflet_js', 'geoPoints', $this->geoPoints);
    }
    /**
     * Generates a map with a single marker based on the given attributes.
     *
     * @param array $atts An array of attributes for the map.
     * @return string The generated map with a single marker.
     */
    public function single_map($atts)
    {
        ob_start(); // Start buffering
        $atts = shortcode_atts(
            array(
                'id' => get_the_ID()
            ),
            $atts

        );
        $post_id = $atts['id'];
        ?>
        <div id="mapid" style="height: 100%; width: 100%; min-height:350px;"></div>
        <script>
            jQuery(document).ready(function () {
                var map = L.map('mapid').setView([52.37052, 9.73322], 10);
                L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
                    maxZoom: 19,
                    attribution: 'Map data © <a href="https://openstreetmap.org">OpenStreetMap</a> contributors'
                }).addTo(map);

                var radiusRanges = [5000, 25000, 50000, 75000, 100000];


                // Fetch jobs
                <?php


                $lat = get_post_meta($post_id, 'latitude', true);
                $lon = get_post_meta($post_id, 'longitude', true);
                if ($lat && $lon) {
                    ?>
                    L.marker([<?= $lat ?>, <?= $lon ?>]).addTo(map)
                        .bindPopup(<?= json_encode(get_the_title($post_id)) ?>);
                    <?php
                }

                ?>




            });
        </script>
        <?php
        return ob_get_clean(); // Output buffered content
    }
    /**
     * Generates a map shortcode with the given attributes.
     *
     * @param array $atts The attributes for the shortcode.
     * @return string The generated map shortcode.
     */
    public function map_shortcode($atts)
    {
        ob_start(); // Start buffering
        ?>
        <div id="mapid" style="height: 500px; width: 100%;"></div>
        <script>
            jQuery(document).ready(function () {
                var map = L.map('mapid').setView([52.37052, 9.73322], 10);
                L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
                    maxZoom: 19,
                    attribution: 'Map data © <a href="https://openstreetmap.org">OpenStreetMap</a> contributors'
                }).addTo(map);

                var radiusRanges = [5000, 25000, 50000, 75000, 100000];


                // Fetch jobs
                <?php
                $args = array(
                    'post_type' => 'job',
                    'post_status' => 'published',
                    'posts_per_page' => -1
                );
                $jobs = get_posts($args);
                foreach ($jobs as $job) {
                    $lat = get_post_meta($job->ID, 'latitude', true);
                    $lon = get_post_meta($job->ID, 'longitude', true);
                    if ($lat && $lon) {
                        ?>
                        L.marker([<?= $lat ?>, <?= $lon ?>]).addTo(map)
                            .bindPopup(<?= json_encode($job->post_title) ?>);
                        <?php
                    }
                }
                ?>
                var colors = ['red', 'orange', 'yellow', 'green', 'blue'];

                for (var i = 0; i < radiusRanges.length; i++) {
                    L.circle([52.37052, 9.73322], {
                        color: colors[i],
                        fillColor: colors[i],
                        fillOpacity: 0.1,
                        radius: radiusRanges[i]
                    }).addTo(map);
                }

            });
        </script>
        <?php
        return ob_get_clean(); // Output buffered content
    }
    /**
     * Adds a new point to the list of geoPoints.
     *
     * @param float $lat The latitude of the point.
     * @param float $lon The longitude of the point.
     */
    public function addPoint($lat, $lon)
    {
        array_push($this->geoPoints, [$lat, $lon]);
    }
}

// Instantiate and use the class
$osm = new OpenStreetMapPlugin();

// Add points
$osm->addPoint(51.5, -0.09);
$osm->addPoint(51.7, -0.12);
$osm->addPoint(51.8, -0.11);