<?PHP
/**
 * Class Class_woocommerce_Helper
 * This class handles woocommerce helpers
 *
 *
 * @package LeadGenerator
 * @since 0.2.1
 */
class Class_woocommerce_Helper
{
    /**
     * Constructs a new instance of the class.
     */
    function __construct()
    {

    }
    /**
     * Displays a product panel with information and options.
     *
     * @param int $product_id The ID of the product to display.
     * @param string $form_link The link to the form for purchasing the product.
     * @return string The rendered HTML for the product panel.
     */
    static function show_product($product_id, $form_link)
    {

        $product = wc_get_product($product_id);

        $fields = get_field_object('delete_period', $product_id);

        $refresh_period = get_field_object('refresh_period', $product_id);
        $refresh_period_value = $refresh_period['choices'][$refresh_period['value']];

        if (!$product || !isset($fields['value'])) {
            return;
        }
        $premium = '';
        $product_premium = get_field('premium', $product_id);
        if ($product_premium == 1) {
            $premium = 'Premium';
        }


        $data = [
            'product_title' => $product->get_title(),
            'product_price' => wc_price($product->get_price()),
            'product_description' => $product->get_description(),
            'product_option_date' => $fields['choices'][$fields['value']],
            'product_premium' => $premium,
            'formular_link' => $form_link,
            'product_refresh' => $refresh_period_value,
        ];
        $template = apply_filters('wp_leadgen_template_path', 'product/panel.twig');
        $rendered_html = Timber::compile($template, $data);
        return $rendered_html;

    }
    /**
     * Creates a new order with the specified product and job ID.
     *
     * @param int $product_id The ID of the product to be added to the order.
     * @param int $job_id The ID of the job associated with the order.
     * @return int The ID of the newly created order.
     */
    static function create_order($product_id, $job_id)
    {
        $order = wc_create_order();

        // Set the order's customer as a guest
        $order->set_customer_id(0);
        $product = wc_get_product($product_id);

        $order->add_product($product, 1);

        // Calculate totals
        $order->calculate_totals();
        $order->update_meta_data('_job_id', $job_id);
        // Save the order
        $order->save();

        return $order->get_id();
    }
    /**
     * Sets the billing address for the specified order.
     *
     * @param int $order_id The ID of the order to set the billing address for.
     * @param array $billing_address The billing address to set for the order.
     * @return void
     */
    static function set_billing_address($order_id, $billing_address)
    {
        $order = wc_get_order($order_id);
        $order->set_billing_address($billing_address);
        $order->save();

    }
    /**
     * Selects a product and renders the HTML using a specified template.
     *
     * @param int $post_id The ID of the post to associate the product with.
     * @param int $product_id The ID of the product to select.
     * @return void
     */
    static function select_product($post_id, $product_id)
    {
        $template = apply_filters('wp_leadgen_template_path', 'admin/select_product.twig');
        $args = array(
            'post_type' => 'product',
            'posts_per_page' => -1,

        );

        $loop = new WP_Query($args);
        $posts = $loop->posts;
        $data = [
            'products' => $posts,
            'post_id' => $post_id,
            'product_id' => $product_id,
        ];
        $rendered_html = Timber::compile($template, $data);
        echo $rendered_html;


    }
    /**
     * Displays the product information for a given product ID.
     *
     * @param int $product_id The ID of the product to display information for.
     * @return void
     */
    static function show_product_info($product_id)
    {
        $product = wc_get_product($product_id);
        $template = apply_filters('wp_leadgen_template_path', 'admin/product_info.twig');
        if ($product) {
            $data = [
                'title' => $product->get_title(),
                'price' => $product->get_regular_price(),
                'id' => $product_id,
                'attributes' => [
                    'delete_period' => get_field('delete_period', $product_id),
                    'premium' => get_field('premium', $product_id),
                ]
            ];
            $rendered_html = Timber::compile($template, $data);
            echo $rendered_html;
        }

    }
    static function show_calendar_info($lead_id)
    {

       
           // echo get_post_meta($lead_id, 'job_start_date', true);
        

    }
    /**
     * Retrieves and displays the order information for a given order ID.
     * 
     * @param int $order_id The ID of the order to retrieve information for.
     * @return void
     */
    static function show_order_info($order_id)
    {
        $order = wc_get_order($order_id);
        if ($order) {

            $order_status = $order->get_status();
            $currency = $order->get_currency();

            $template = apply_filters('wp_leadgen_template_path', 'admin/order_info.twig');

            $invoice = $order->get_invoice();
            $data = [
                'order' => $order,
                'order_id' => $order->get_id(),
                'currency' => $currency,
                'invoice' => $invoice,
                'order_status' => $order_status,
            ];
            $rendered_html = Timber::compile($template, $data);
            echo $rendered_html;

        }

    }

}
