<?php

/**
 * Plugin Name:     LeadGenerator 
 * Plugin URI:      https://lightweb-media.de
 * Description:     LeadGenerator for Jobs
 * Author:          Sebastian Weiß
 * Author URI:      https://lightweb-media.de/
 * Text Domain:     leadgenerator
 * Domain Path:     /languages
 * Version:         2.0.14
 * Requires Plugins: woocommerce, contact-form-7, advanced-custom-fields-pro, cf7-conditional-fields, ultimate-member 
 * Update URI: https://plugins.lightweb-media.de/api?action=get_metadata&slug=wp-leadgenerator
 */

defined('ABSPATH') || exit;

define('LGenURL', plugin_dir_url(__FILE__));
define('LGenPath', plugin_dir_path(__FILE__));

if (file_exists(LGenPath . 'vendor/autoload.php')) {
    require LGenPath . 'vendor/autoload.php';
}

add_action('wp_enqueue_scripts', 'load_google_maps_api');
function load_google_maps_api()
{
    $api_key = get_option('leadgen_google_api_key');
    $url = 'https://maps.googleapis.com/maps/api/js?key=' . $api_key . '&libraries=places&language=de';
    wp_enqueue_script('google-maps', $url, array(), null, true);
    add_filter('script_loader_tag', 'add_async_attribute', 10, 3);

}

function add_async_attribute($tag, $handle, $src)
{
    if ('google-maps' === $handle) {
        $tag = str_replace(' src', ' async src', $tag);
    }
    return $tag;
}





require_once __DIR__ . '/vendor/autoload.php';

Timber\Timber::init();

use Timber\Timber;


Timber::$locations = LGenPath . 'templates';

include_once(LGenPath . 'post-types/lgen-company.php');
include_once(LGenPath . 'post-types/lgen-leads.php');
include_once(LGenPath . 'cf7.ext.php');
include_once(LGenPath . 'classes/class-leadpost.php');
include_once(LGenPath . 'classes/class-leadgen.php');
include_once(LGenPath . 'classes/class-woocommerce.php');
include_once(LGenPath . 'classes/class-adminview.php');
include_once(LGenPath . 'classes/class-cf7.php');
include_once(LGenPath . 'classes/class-osm.php');
include_once(LGenPath . 'acf/fields.php');
include_once(LGenPath . 'acf/helper.php');
include_once(LGenPath . 'classes/Filter.php');
include_once(LGenPath . 'classes/class-wishlist.php');
include_once(LGenPath . 'classes/class-calendar.php');
include_once(LGenPath . 'classes/class-map.php');
include_once(LGenPath . 'classes/class-shortcode.php');
include_once(LGenPath . 'classes/class-accounts.php');

if (!WPCF7_AUTOP) {
    define('WPCF7_AUTOP', false);
}

/**
 * Registers the 'wishlist_icon' shortcode.
 * @Shortcode
 * @param callable $callback The callback function that will be called when the [wishlist_icon] shortcode is used.
 */

add_shortcode('wishlist_icon', 'show_wishlist_icon');
add_shortcode('wishlist', 'wishlist');
/**
 * Returns the HTML code for displaying the wishlist icon.
 *
 * @return string The HTML code for the wishlist icon.
 */
function show_wishlist_icon()
{
    return WishList::show_whistlist_icon();
}
/**
 * Wishlist function.
 *
 * This function calls the my_shortcode_callback method of the WishList class, passing in the $atts and $content parameters.
 *
 * @param array $atts An array of attributes for the shortcode.
 * @return string The output of the my_shortcode_callback method.
 */
function wishlist($atts = array(), $content = null)
{
    return WishList::my_shortcode_callback($atts, $content = null);
}
/**
 * Displays the product panel with the given attributes.
 *
 * @param array $atts Optional. An array of attributes for the product panel.
 * @return string The HTML code for the product panel.
 */
function show_product_panel($atts = array(), $content = null, $tag = '')
{
    $atts = array_change_key_case((array) $atts, CASE_LOWER);

    // override default attributes with user attributes
    $wporg_atts = shortcode_atts(
        array(
            'product_id' => '',
            'formular_link' => get_site_url() . '/job-einstellen/' . '?product_id=' . $atts['product_id'] . '#job_formular'
        ),
        $atts,
        $tag
    );
    if ($wporg_atts['product_id']) {
        return Class_woocommerce_Helper::show_product($wporg_atts['product_id'], $wporg_atts['formular_link']);
    } else {
        return '';
    }
}

add_shortcode('product_panel', 'show_product_panel');


if (!has_filter('wp_nav_menu', 'do_shortcode')) {
    add_filter('wp_nav_menu', 'shortcode_unautop');
    add_filter('wp_nav_menu', 'do_shortcode', 11);
}

add_action('plugins_loaded', function () {
    new Class_cf7_Helper();
});



add_action('init', function () {

    new LGenQuery();
    new LeadGeneratorInit();
    new LGenPost();
    new Filter();
    new WishList();
});

class LeadGeneratorInit
{
    /**
     * Constructor method for the class.
     * Adds an action to enqueue scripts on the WordPress front-end.
     *
     * @return void
     */
    function __construct()
    {

        add_action('wp_enqueue_scripts', [$this, 'load_styles']);
    }
    /**
     * Loads the necessary styles and scripts for the plugin.
     *
     * @return void
     */
    public function load_styles()
    {
        wp_enqueue_style('main', LGenURL . 'assets/css/main.css', [], []);
        wp_enqueue_style('auto', LGenURL . 'assets/css/autocomplete.css', [], []);
        wp_enqueue_script('autocomplete', LGenURL . 'assets/js/autocomplete.min.js', [], []);
    }
}
/**
 * Adds a filter to modify the content of posts in the 'job' post type archive.
 *
 * @param WP_Query $query The main query object.
 * @return void
 */
function custom_post_type_archive_content($query)
{
    if (!is_admin() && $query->is_main_query() && is_post_type_archive('job')) {
        add_filter('the_content', 'modify_post_content');
    }
}




add_action('admin_init', 'rpt_add_role_caps', 999);
/**
 * Adds custom capabilities to the 'ma' user role.
 *
 * @return void
 */
function rpt_add_role_caps()
{

    $role = get_role('ma');
    $role->add_cap('read_job');
    $role->add_cap('edit_job');
    $role->add_cap('edit_jobs');
    $role->add_cap('edit_other_jobs');
    $role->add_cap('edit_published_jobs');
    $role->add_cap('publish_jobs');
    $role->add_cap('read_private_jobs');
    $role->add_cap('delete_job');
}

//add_filter('register_post_type_args', 'change_capabilities_of_job', 10, 2);
/**
 * Changes the capabilities of the "job" post type.
 *
 * @param array $args The original arguments for the post type.
 * @param string $post_type The post type to change capabilities for.
 * @return array The modified arguments for the post type.
 */
function change_capabilities_of_job($args, $post_type)
{

    // Do not filter any other post type
    if ('job' !== $post_type) {
        // Give other post_types their original arguments
        return $args;
    }

    // Change the capabilities of the "job" post_type
    $args['capabilities'] = array(
        'edit_post' => 'edit_job',
        'edit_posts' => 'edit_jobs',
        'edit_others_posts' => 'edit_other_jobs',
        'publish_posts' => 'publish_jobs',
        'read_post' => 'read_job',
        'read_private_posts' => 'read_private_jobs',
        'delete_post' => 'delete_job'
    );

    // Give the job post type it's arguments
    return $args;
}
/**
 * Adds 'twig' to the list of editable extensions.
 *
 * @param array $editable_extensions List of editable extensions.
 * @return array Updated list of editable extensions.
 */
function add_twig_to_editable_extensions($editable_extensions)
{

    $editable_extensions[] = 'twig';

    return $editable_extensions;
}
add_filter('editable_extensions', 'add_twig_to_editable_extensions');


// The action callback function. 
/**
 * Retrieves the URL of the attachment with the given ID.
 *
 * @param int $attachment_id The ID of the attachment.
 * @return string|false The URL of the attachment, or false if no attachment found.
 */
function example_callback_id_generated($attachment_id)
{
    // (maybe) do something with the args. 
    $url = wp_get_attachment_url($attachment_id);
}
add_action('nmr_create_attachment_id_generated', 'example_callback_id_generated', 10, 1);
/**
 * Registers a custom post status called "Pre-pending" for the "job" post type.
 *
 * @since 1.0.0
 *
 * @param none
 * @return none
 */
function custom_post_status()
{
    register_post_status(
        'pre-pending',
        array(
            'label' => _x('Pre-pending', 'job'),
            'public' => false,
            'private' => true,
            'exclude_from_search' => false,
            'show_in_admin_all_list' => true,
            'show_in_admin_status_list' => true,
            'label_count' => _n_noop('Pre-pending <span class="count">(%s)</span>', 'Pre-pending <span class="count">(%s)</span>'),
        )
    );
}
add_action('init', 'custom_post_status');
/**
 * Registers a custom post status named "archive".
 *
 * @since 1.0.0
 *
 * @param none
 * @return none
 */
function jc_custom_post_status()
{
    register_post_status(
        'archive',
        array(
            'label' => _x('Archive', 'post'),
            'public' => true,
            'show_in_admin_all_list' => false,
            'show_in_admin_status_list' => true,
            'label_count' => _n_noop('Archive <span class="count">(%s)</span>', 'Archive <span class="count">(%s)</span>')
        )
    );
}
/**
 * Appends a custom post status option and label to the post status dropdown menu and post status display.
 *
 * @global WP_Post $post The current post object.
 *
 * @return void
 */
function append_post_status_list()
{

    global $post;
    $complete = '';
    $label = '';
    if (!isset($post)) {
        return;
    }
    if ($post->post_type == 'job') {

        if ($post->post_status == 'pre-pending') {
            $complete = ' selected="selected"';
            $label = '<span id="post-status-display"> Pre-pending</span>';
        }
        ?>
        <script>
            jQuery(document).ready(function ($) {
                $("select#post_status").append("<option value='pre-pending' <?php echo $complete; ?>>Pre-pending</option>");
                $(".misc-pub-section label").append("<?php echo $label ?>");
            });
        </script>
        <?php
    }
}
add_action('admin_footer', 'append_post_status_list');
/**
 * Adds additional query variables to the existing list of variables.
 *
 * @param array $vars The existing list of query variables.
 * @return array The updated list of query variables.
 */
function add_query_vars_filter($vars)
{
    $vars[] = "distance";
    $vars[] = "longitude";
    $vars[] = "latitude";
    return $vars;
}
add_filter('query_vars', 'add_query_vars_filter');
/**
 * Converts a UUID to a post slug for the 'job' post type.
 *
 * @param array $data The post data to be modified.
 * @param array $postarr The post data before any modifications.
 * @return array The modified post data.
 */
function uuid_as_post_slug($data, $postarr)
{
    if ($data['post_type'] == 'job') {
        $uuid = get_post_meta($postarr['ID'], 'uuid', true);
        if (!empty($uuid)) {

            $data['post_name'] = sanitize_title($uuid);
        } else {
            $data['post_name'] = uniqid();
        }
    }
    return $data;
}
add_filter('wp_insert_post_data', 'uuid_as_post_slug', 10, 2);


add_action('template_redirect', 'custom_single_post_redirect');
/**
 * Redirects the user to an external link if the current post is a job post.
 *
 * @return void
 */
function custom_single_post_redirect()
{
    if (is_singular('job')) {
        $external_link = get_post_meta(get_the_ID(), 'job_link', true);
        if ($external_link) {
            wp_redirect($external_link);
            exit;
        }
    }
}
/**
 * Registers a custom post status called "unconfirmed".
 *
 * @since 1.0.0
 *
 * @param void
 * @return void
 */
function my_custom_status_creation()
{
    register_post_status(
        'unconfirmed',
        array(
            'label' => _x('Nicht bestätigt', 'post'),
            'label_count' => _n_noop('Nicht bestätigt <span class="count">(%s)</span>', 'Nicht bestätigt <span  class="count">(%s)</span>'),
            'public' => false,
            'exclude_from_search' => false,
            'show_in_admin_all_list' => true,
            'show_in_admin_status_list' => true
        )
    );
}
add_action('init', 'my_custom_status_creation');
/**
 * Adds the option "Nicht bestätigt" to the post status dropdown for job posts.
 *
 * @return bool False if the post type is not "job", otherwise true.
 */
function add_to_post_status_dropdown()
{
    global $post;
    if ($post->post_type != 'job')
        return false;
    $status = ($post->post_status == 'unconfirmed') ? "jQuery( '#post-status-display' ).text( 'Nicht bestätigt' ); jQuery( 
'select[name=\"post_status\"]' ).val('unconfirmed');" : '';
    echo "<script>
jQuery(document).ready( function() {
jQuery( 'select[name=\"post_status\"]' ).append( '<option value=\"unconfirmed\">Nicht bestätigt</option>' );
" . $status . "
});
</script>";
}
add_action('post_submitbox_misc_actions', 'add_to_post_status_dropdown');


if (!has_filter('wp_nav_menu', 'do_shortcode')) {
    add_filter('wp_nav_menu', 'shortcode_unautop');
    add_filter('wp_nav_menu', 'do_shortcode', 11);
}
/**
 * Sets the custom excerpt length to 21 characters.
 *
 * @param int $length The length of the excerpt.
 * @return int The custom excerpt length of 21 characters.
 */
function leadgen_custom_excerpt_length($length)
{
    return 21;
}
add_filter('excerpt_length', 'leadgen_custom_excerpt_length', 999);
















add_action('leadgen_job_confirmed', 'send_mail');
/**
 * Sends an email with the job data to the admin.
 *
 * @param array $job The job data.
 */
function send_mail($job)
{

    // Daten aus dem Post holen
    $posted_data = get_post_meta($job['ID'], '');
    if (is_array($posted_data)) {
        foreach ($posted_data as $key => $value) {
            if (is_array($value) && count($value) > 0 && is_serialized($value[0])) {
                $posted_data[$key] = unserialize($value[0]);
            } else {
                $posted_data[$key] = $value[0];
            }
        }
    }


    $to = get_option('admin_mails');
    if (empty($to)) {
        $to = get_option('admin_email');
    }

    $subject = 'Neue Anzeige';
    $headers = array('Content-Type: text/html; charset=UTF-8');

    $product = wc_get_product($posted_data['product'][0]);
    if (isset($product) && $product) {
        $posted_data['product']['name'] = $product->get_name();
        $posted_data['product']['price'] = $product->get_price();
        $posted_data['product']['premium'] = get_post_meta($posted_data['product'][0], 'premium', True);
    }
 

    //var_dump($posted_data);
    $template = apply_filters('wp_leadgen_template_path', '/mail/admin-job-sucess-body.twig');

    $posted_data['edit_link'] = get_site_url();
    $posted_data['ID'] = $job['ID'];


    $posted_data['job']['terms'] = [];
    foreach ($posted_data["job_form_of_employment_terms"] as $term_id) {
        $posted_data['job']['terms']["job_form_of_employment_terms"][] = get_term($term_id)->name;
    }
    foreach ($posted_data["jobcategory_terms"] as $term_id) {
        $posted_data['job']['terms']["jobcategory_terms"][] = get_term($term_id)->name;
    }
    foreach ($posted_data["job_working_time_terms"] as $term_id) {
        $posted_data['job']['terms']["job_working_time_terms"][] = get_term($term_id)->name;
    }
    foreach ($posted_data["job_type_terms"] as $term_id) {
        $posted_data['job']['terms']["job_type_terms"][] = get_term($term_id)->name;
    }


    $posted_data['product']['condition'] = [
        'refresh' => get_post_meta($posted_data['product'][0], 'refresh', True),
        'delete' => get_post_meta($posted_data['product'][0], 'delete', True)
    ];

    $body = Timber::compile($template, $posted_data);
    wp_mail($to, $subject, $body, $headers);
    //   var_dump($posted_data);

}

// Register new field to user's API
add_action('rest_api_init', 'register_user_fields');
/**
 * Registers a new REST field for the user object.
 *
 * This function registers a new field called 'woocommerce' for the 'user' object,
 * which will be used to retrieve user meta data related to the WooCommerce plugin.
 *
 * @since 1.0.0
 *
 * @param string $object_type The type of object to register the field for.
 * @param string $field_name The name of the field to register.
 * @param array $args Optional. Additional arguments for registering the field.
 * @return void
 */
function register_user_fields()
{
    register_rest_field(
        'user',
        'woocommerce',
        array(
            // Gets the user meta
            'get_callback' => 'get_user_woocommerce_data',
            'update_callback' => null,
            'schema' => null,
        )
    );
}

add_filter('woocommerce_billing_fields', 'custom_woocommerce_billing_fields');
/**
 * Adds a custom field for the billing section in WooCommerce.
 *
 * @param array $fields The array of billing fields.
 * @return array The updated array of billing fields.
 */
function custom_woocommerce_billing_fields($fields)
{
    $fields['anrede'] = array(
        'type' => 'select',
        'label' => __('Anrede', 'woocommerce'),
        'options' => array(
            'Herr' => 'Herr',
            'Frau' => 'Frau',
            'Divers' => 'Divers'
        ),
        'class' => array('form-row-wide'),
        'required' => false,
        'clear' => true
    );

    // Get the custom field and remove it from the end
    $custom_field = $fields['anrede'];
    unset($fields['anrede']);

    // Add the custom field back to the beginning of the fields array
    $fields = array('anrede' => $custom_field) + $fields;

    return $fields;
}

// Return custom user WooCommerce meta
/**
 * Retrieves WooCommerce data for a specific user.
 *
 * @param array $user The user's data.
 * @param string $field_name The name of the field to retrieve.
 * @param string $request The type of data to retrieve.
 *
 * @return array The user's WooCommerce data.
 */
function get_user_woocommerce_data($user, $field_name, $request)
{
    $user_id = $user['id'];
    $customer = new WC_Customer($user_id);

    $user_wc_data = array(
        'billing_address' => [
            'customer_firstname' => $customer->billing_first_name,
            'customer_lastname' => $customer->billing_last_name,
            'customer_company' => $customer->billing_company,
            'customer_street' => $customer->address,
            'customer_city' => $customer->billing_city,
            'customer_state' => $customer->billing_state,
            'customer_zip' => $customer->billing_postcode,
            'customer_mail' => $customer->email,
            'customer_country' => $customer->billing_country,
            'anrede' => get_user_meta($user_id, 'anrede', true)

        ]
    );

    return $user_wc_data;
}

add_action('woocommerce_customer_save_address', 'custom_field_save_address', 10, 2);
/**
 * Saves the user's address information.
 *
 * @param int $user_id The ID of the user whose address is being saved.
 * @param bool $load_address Whether or not to load the address from the $_POST variable.
 * @return void
 */
function custom_field_save_address($user_id, $load_address)
{
    update_user_meta($user_id, 'anrede', $_POST['anrede']);
}
/**
 * Adds a custom orderby parameter to the given query parameters.
 *
 * @param array $query_params The query parameters to modify.
 * @return array The modified query parameters with the custom orderby parameter added.
 */
function my_custom_orderby($query_params)
{
    $query_params['orderby'] = array(
        'description' => 'Random order',
        'type' => 'string',
        'enum' => array('rand', 'date', 'title', 'id', 'distance'),
    );

    return $query_params;
}
/**
 * Customizes the query arguments for ordering results.
 *
 * @param array $args The original query arguments.
 * @param array $request The request parameters.
 * @return array The modified query arguments.
 */
function my_custom_orderby_query($args, $request)
{
    if (isset($request['rand']) && 'rand' === $request['orderby']) {
        $seed = isset($_COOKIE['random_seed']) ? $_COOKIE['random_seed'] : rand();


        $args['orderby'] = 'RAND(' . $seed . ')';
    }

    if (isset($request['date']) && 'date' === $request['orderby']) {
  
            $args['orderby'] = $args['meta_value_num'];
            $args['meta_key'] = $args['job_start_date'];
        
    }


    return $args;
}
add_filter('rest_job_query', 'my_custom_orderby_query', 10, 2);
add_filter('rest_job_collection_params', 'my_custom_orderby', 10, 1);
/**
 * Removes the specified email from the WordPress database.
 *
 * @param string $email The email address to be removed.
 * @return string The name of the WordPress blog.
 */
function remove_from_wordpress($email)
{
    $wpfrom = get_option('blogname');
    return $wpfrom;
}

add_filter('wp_mail_from_name', 'remove_from_wordpress');
/**
 * Exclude custom post types from specific taxonomies in the query.
 *
 * @param WP_Query $query The current query object.
 */
function exclude_cpt_from_taxonomies($query)
{

    if ($query->is_main_query() && is_tax('jobcategory') && is_archive()) {
        $query->set('post_type', 'job', 'nav_menu_item', 'page', 'wp_navigation', 'nav_menu_item', 'wp_template_part', 'wp_template'); // Set to the CPTs you want to include
    }

}

add_action('pre_get_posts', 'exclude_cpt_from_taxonomies');
/**
 * Modifies the term clauses for a specific taxonomy and post types.
 *
 * @param array $clauses The current term clauses.
 * @param string $taxonomy The taxonomy being queried.
 * @param array $args The arguments for the query.
 * @return array The modified term clauses.
 */
function my_terms_clauses($clauses, $taxonomy, $args)
{
    global $wpdb;

    if (isset($args['post_types'])) {
        $post_types = $args['post_types'];

        // allow for arrays
        if (is_array($args['post_types'])) {
            $post_types = implode("','", $args['post_types']);
        }

        $clauses['join'] .= " INNER JOIN $wpdb->term_relationships AS r ON r.term_taxonomy_id = tt.term_taxonomy_id INNER JOIN $wpdb->posts AS p ON p.ID = r.object_id ";
        $clauses['where'] .= " AND p.post_type IN ('" . esc_sql($post_types) . "')  GROUP BY t.term_id ";
    }

    return $clauses;
}
add_filter('terms_clauses', 'my_terms_clauses', 99999, 3);
/**
 * Retrieves the number of posts associated with a specific term in a given taxonomy and post type.
 *
 * @param int $term_id The ID of the term to retrieve the post count for.
 * @param string $taxonomy The taxonomy of the term.
 * @param string $post_type The post type to retrieve the post count for.
 * @return int The number of posts associated with the given term in the specified taxonomy and post type.
 */
function get_term_count($term_id, $taxonomy, $post_type)
{
    global $wpdb;

    $query = "
        SELECT COUNT(*) FROM $wpdb->posts
        LEFT JOIN $wpdb->term_relationships ON ($wpdb->posts.ID = $wpdb->term_relationships.object_id)
        LEFT JOIN $wpdb->term_taxonomy ON ($wpdb->term_relationships.term_taxonomy_id = $wpdb->term_taxonomy.term_taxonomy_id)
        WHERE $wpdb->posts.post_status = 'publish' 
        AND $wpdb->posts.post_type = '%s' 
        AND $wpdb->term_taxonomy.taxonomy = '%s'
        AND $wpdb->term_taxonomy.term_id = %d
    ";

    $term_count = $wpdb->get_var($wpdb->prepare($query, $post_type, $taxonomy, $term_id));

    return $term_count;
}
/**
 * Updates the related_jobs field in the company post with the IDs of related jobs.
 *
 * @param int $post_id The ID of the job post being updated.
 * @return void
 */
function update_related_jobs($post_id)
{
    // Ensure this is a job post type
    if (get_post_type($post_id) != 'job')
        return;

    // Get the company_id field of job
    $company_id = get_field('company_id', $post_id);

    if ($company_id) {
        // Find related jobs
        $related_jobs = get_posts([
            'post_type' => 'job',
            'posts_per_page' => -1,
            'meta_query' => [
                [
                    'key' => 'company_id', // name of custom field in job
                    'value' => '"' . $company_id . '"',
                    'compare' => 'LIKE'
                ]
            ]
        ]);

        // Loop through related jobs and collect their IDs
        $job_ids = [];
        if ($related_jobs) {
            foreach ($related_jobs as $job) {
                $job_ids[] = $job->ID;
            }
        }

        // Update the related_jobs field in the company post
        update_field('related_jobs', $job_ids, $company_id);
    }
}

// Hook into save post
add_action('acf/save_post', 'update_related_jobs', 20);
/**
 * Updates the related_jobs field in a company post with the IDs of related jobs.
 *
 * @param int $post_id The ID of the company post.
 * @return void
 */
function update_related_jobs_company($post_id)
{
    // Ensure this is a company post type
    if (get_post_type($post_id) != 'company')
        return;

    // Find related jobs
    $related_jobs = get_posts([
        'post_type' => 'job',
        'posts_per_page' => -1,
        'meta_query' => [
            [
                'key' => 'company_id', // name of custom field in job
                'value' => '"' . $post_id . '"',
                'compare' => 'LIKE'
            ]
        ]
    ]);

    // Loop through related jobs and collect their IDs
    $job_ids = [];
    if ($related_jobs) {
        foreach ($related_jobs as $job) {
            $job_ids[] = $job->ID;
        }
    }

    // Update the related_jobs field in the company post
    update_field('related_jobs', $job_ids, $post_id);
}

// Hook into save post
add_action('acf/save_post', 'update_related_jobs_company', 20);


function set_random_seed_cookie()
{
    if (!isset($_COOKIE['random_seed'])) {
        $random_seed = rand();
        // Set the cookie to expire in one hour
        setcookie('random_seed', $random_seed, time() + 3600, COOKIEPATH, COOKIE_DOMAIN);
    }
}
add_action('init', 'set_random_seed_cookie');

function custom_taxonomy_order($query)
{
    global $wp_query;
    $seed = isset($_COOKIE['random_seed']) ? $_COOKIE['random_seed'] : rand();

    // Check if the query is for an archive
    if (is_archive()) {
        if (!is_admin()) {


            $query->set('orderby', 'RAND(' . $seed . ')');
            return;
        }
    }
}
//add_action('pre_get_posts', 'custom_taxonomy_order');



//add_filter('shortcode_atts_wpcf7', 'custom_file_tag_arguments', 10, 3);

function update_acf_field_on_publish( $post_id ) {
    if ( get_post_type($post_id) != 'job' ) {
        return;
    }
    if ( get_post_status( $post_id ) === 'publish' ) {
        $job_start_date = get_post_meta($post_id, 'job_start_date', true);
    
        if (!$job_start_date) {
            $field_value = current_time('Ymd'); // Value to update the field with
    
            
            $LGenQuery = new LGenQuery();
            $order_id =  $LGenQuery->get_order_id($post_id );
            $product_id =  $LGenQuery->get_product_id($order_id );
       
            $delete_period = get_post_meta($product_id, 'delete_period', true);
            $delete_period = rtrim($delete_period, 'd');
            $refresh_period = get_post_meta($product_id, 'refresh_period', true);
            $refresh_period = rtrim($refresh_period, 'd');
    
            $refresh_date = new DateTime(   $field_value);
            $refresh_date->modify(modifier: "+" . $refresh_period . " days");
            $expiry_date = new DateTime(   $field_value);
    
            $expiry_date->modify(modifier: "+" . $delete_period . " days");
            
            update_post_meta($post_id, 'job_ad_deadline', $expiry_date->format("Ymd"));
            update_field( 'job_start_date', $field_value, $post_id ); // Replace 'field_name' with the ACF field name
            update_post_meta($post_id, 'job_refresh_date', $refresh_date->format("Ymd"));
            
        
        }
     
    }
  
}
add_action( 'save_post', 'update_acf_field_on_publish', 10, 1 );

