<?php

/**
 * Registers the `lg_leads` post type.
 */
function lgen_company_init()
{
    register_post_type(
        'company',
        [
            'labels' => [
                'name' => __('Unternehmensprofile', 'LeadGenerator'),
                'singular_name' => __('Unternehmensprofil', 'LeadGenerator'),
                'all_items' => __('Alle Unternehmensprofile', 'LeadGenerator'),
                'attributes' => __('Unternehmensprofil Attributes', 'LeadGenerator'),
                'insert_into_item' => __('Insert into Unternehmensprofil', 'LeadGenerator'),
                'uploaded_to_this_item' => __('Uploaded to this Unternehmensprofil', 'LeadGenerator'),
                'featured_image' => _x('Featured Image', 'Company', 'LeadGenerator'),
                'set_featured_image' => _x('Set featured image', 'Company', 'LeadGenerator'),
                'remove_featured_image' => _x('Remove featured image', 'Company', 'LeadGenerator'),
                'use_featured_image' => _x('Use as featured image', 'Company', 'LeadGenerator'),
                'filter_items_list' => __('Filter Company list', 'LeadGenerator'),
                'items_list_navigation' => __('Company list navigation', 'LeadGenerator'),
                'items_list' => __('Company list', 'LeadGenerator'),
                'new_item' => __('Neues Unternehmensprofil', 'LeadGenerator'),
                'add_new' => __('Add New', 'LeadGenerator'),
                'add_new_item' => __('Add New Company', 'LeadGenerator'),
                'edit_item' => __('Edit Company', 'LeadGenerator'),
                'view_item' => __('View Company', 'LeadGenerator'),
                'view_items' => __('View Company', 'LeadGenerator'),
                'search_items' => __('Search Company', 'LeadGenerator'),
                'not_found' => __('No Company found', 'LeadGenerator'),
                'not_found_in_trash' => __('No Company found in trash', 'LeadGenerator'),
                'parent_item_colon' => __('Parent Company:', 'LeadGenerator'),
                'menu_name' => __('Unternehmensprofile', 'LeadGenerator'),
            ],
            'public' => true,
            'hierarchical' => false,
            'show_ui' => true,
            'show_in_nav_menus' => true,
            'supports' => ['editor', 'title', 'custom-fields', 'thumbnail', 'excerpt'],
            'has_archive' => true,
            'rewrite' => array(
                'slug' => 'unternehmen'
            ),


            'query_var' => false,
            'menu_position' => null,
            'menu_icon' => 'dashicons-admin-post',
            'show_in_rest' => false,
            'rest_base' => 'job',
            'rest_controller_class' => 'WP_REST_Posts_Controller',
        ]
    );

}

add_action('init', 'lgen_company_init');

/**
 * Sets the post updated messages for the `lgen_leads` post type.
 *
 * @param  array $messages Post updated messages.
 * @return array Messages for the `lgen_leads` post type.
 */
function lgen_company_updated_messages($messages)
{
    global $post;

    $permalink = get_permalink($post);

    $messages['job'] = [
        0 => '', // Unused. Messages start at index 1.
        /* translators: %s: post permalink */
        1 => sprintf(__('Lg leads updated. <a target="_blank" href="%s">View lg leads</a>', 'LeadGenerator'), esc_url($permalink)),
        2 => __('Custom field updated.', 'LeadGenerator'),
        3 => __('Custom field deleted.', 'LeadGenerator'),
        4 => __('Lg leads updated.', 'LeadGenerator'),
        /* translators: %s: date and time of the revision */
        5 => isset($_GET['revision']) ? sprintf(__('Lg leads restored to revision from %s', 'LeadGenerator'), wp_post_revision_title((int) $_GET['revision'], false)) : false, // phpcs:ignore WordPress.Security.NonceVerification.Recommended
        /* translators: %s: post permalink */
        6 => sprintf(__('Lg leads published. <a href="%s">View lg leads</a>', 'LeadGenerator'), esc_url($permalink)),
        7 => __('Lg leads saved.', 'LeadGenerator'),
        /* translators: %s: post permalink */
        8 => sprintf(__('Lg leads submitted. <a target="_blank" href="%s">Preview lg leads</a>', 'LeadGenerator'), esc_url(add_query_arg('preview', 'true', $permalink))),
        /* translators: 1: Publish box date format, see https://secure.php.net/date 2: Post permalink */
        9 => sprintf(__('Lg leads scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview lg leads</a>', 'LeadGenerator'), date_i18n(__('M j, Y @ G:i', 'LeadGenerator'), strtotime($post->post_date)), esc_url($permalink)),
        /* translators: %s: post permalink */
        10 => sprintf(__('Lg leads draft updated. <a target="_blank" href="%s">Preview lg leads</a>', 'LeadGenerator'), esc_url(add_query_arg('preview', 'true', $permalink))),
    ];

    return $messages;
}

add_filter('post_updated_messages', 'lgen_company_updated_messages');

/**
 * Sets the bulk post updated messages for the `lgen_leads` post type.
 *
 * @param  array $bulk_messages Arrays of messages, each keyed by the corresponding post type. Messages are
 *                              keyed with 'updated', 'locked', 'deleted', 'trashed', and 'untrashed'.
 * @param  int[] $bulk_counts   Array of item counts for each message, used to build internationalized strings.
 * @return array Bulk messages for the `lgen_leads` post type.
 */
function lgen_company_bulk_updated_messages($bulk_messages, $bulk_counts)
{
    global $post;

    $bulk_messages['job'] = [
        /* translators: %s: Number of lg leads. */
        'updated' => _n('%s lg leads updated.', '%s lg leads updated.', $bulk_counts['updated'], 'LeadGenerator'),
        'locked' => (1 === $bulk_counts['locked']) ? __('1 lg leads not updated, somebody is editing it.', 'LeadGenerator') :
            /* translators: %s: Number of lg leads. */
            _n('%s lg leads not updated, somebody is editing it.', '%s lg leads not updated, somebody is editing them.', $bulk_counts['locked'], 'LeadGenerator'),
        /* translators: %s: Number of lg leads. */
        'deleted' => _n('%s lg leads permanently deleted.', '%s lg leads permanently deleted.', $bulk_counts['deleted'], 'LeadGenerator'),
        /* translators: %s: Number of lg leads. */
        'trashed' => _n('%s lg leads moved to the Trash.', '%s lg leads moved to the Trash.', $bulk_counts['trashed'], 'LeadGenerator'),
        /* translators: %s: Number of lg leads. */
        'untrashed' => _n('%s lg leads restored from the Trash.', '%s lg leads restored from the Trash.', $bulk_counts['untrashed'], 'LeadGenerator'),
    ];

    return $bulk_messages;
}

add_filter('bulk_post_updated_messages', 'lgen_company_updated_messages', 10, 2);
