<?php

/**
 * Registers the `lg_leads` post type.
 */
function lgen_leads_init()
{
	register_post_type(
		'job',
		[
			'labels' => [
				'name' => __('Job', 'LeadGenerator'),
				'singular_name' => __('Job', 'LeadGenerator'),
				'all_items' => __('All Job', 'LeadGenerator'),
				'archives' => __('Job Archives', 'LeadGenerator'),
				'attributes' => __('Job Attributes', 'LeadGenerator'),
				'insert_into_item' => __('Insert into Job', 'LeadGenerator'),
				'uploaded_to_this_item' => __('Uploaded to this Job', 'LeadGenerator'),
				'featured_image' => _x('Featured Image', 'job', 'LeadGenerator'),
				'set_featured_image' => _x('Set featured image', 'job', 'LeadGenerator'),
				'remove_featured_image' => _x('Remove featured image', 'job', 'LeadGenerator'),
				'use_featured_image' => _x('Use as featured image', 'job', 'LeadGenerator'),
				'filter_items_list' => __('Filter Leads list', 'LeadGenerator'),
				'items_list_navigation' => __('Leads list navigation', 'LeadGenerator'),
				'items_list' => __('Leads list', 'LeadGenerator'),
				'new_item' => __('New Leads', 'LeadGenerator'),
				'add_new' => __('Add New', 'LeadGenerator'),
				'add_new_item' => __('Add New Leads', 'LeadGenerator'),
				'edit_item' => __('Edit Leads', 'LeadGenerator'),
				'view_item' => __('View Leads', 'LeadGenerator'),
				'view_items' => __('View Leads', 'LeadGenerator'),
				'search_items' => __('Search Leads', 'LeadGenerator'),
				'not_found' => __('No Leads found', 'LeadGenerator'),
				'not_found_in_trash' => __('No Leads found in trash', 'LeadGenerator'),
				'parent_item_colon' => __('Parent Leads:', 'LeadGenerator'),
				'menu_name' => __('Leads', 'LeadGenerator'),
			],
			'public' => true,
			'hierarchical' => false,
			'show_ui' => true,
			'show_in_nav_menus' => true,
			'supports' => ['editor', 'title', 'custom-fields', 'thumbnail', 'excerpt'],
			'has_archive' => true,
			'rewrite' => array(
				'slug' => 'jobs'
			),


			'query_var' => true,
			'menu_position' => null,
			'menu_icon' => 'dashicons-admin-post',
			'show_in_rest' => true,
			'rest_base' => 'jobs',
			'rest_controller_class' => 'WP_REST_Posts_Controller',
		]
	);

}

add_action('init', 'lgen_leads_init');

/**
 * Sets the post updated messages for the `lgen_leads` post type.
 *
 * @param  array $messages Post updated messages.
 * @return array Messages for the `lgen_leads` post type.
 */
function lgen_leads_updated_messages($messages)
{
	global $post;

	$permalink = get_permalink($post);

	$messages['job'] = [
		0 => '', // Unused. Messages start at index 1.
		/* translators: %s: post permalink */
		1 => sprintf(__('Lg leads updated. <a target="_blank" href="%s">View lg leads</a>', 'LeadGenerator'), esc_url($permalink)),
		2 => __('Custom field updated.', 'LeadGenerator'),
		3 => __('Custom field deleted.', 'LeadGenerator'),
		4 => __('Lg leads updated.', 'LeadGenerator'),
		/* translators: %s: date and time of the revision */
		5 => isset($_GET['revision']) ? sprintf(__('Lg leads restored to revision from %s', 'LeadGenerator'), wp_post_revision_title((int) $_GET['revision'], false)) : false, // phpcs:ignore WordPress.Security.NonceVerification.Recommended
		/* translators: %s: post permalink */
		6 => sprintf(__('Lg leads published. <a href="%s">View lg leads</a>', 'LeadGenerator'), esc_url($permalink)),
		7 => __('Lg leads saved.', 'LeadGenerator'),
		/* translators: %s: post permalink */
		8 => sprintf(__('Lg leads submitted. <a target="_blank" href="%s">Preview lg leads</a>', 'LeadGenerator'), esc_url(add_query_arg('preview', 'true', $permalink))),
		/* translators: 1: Publish box date format, see https://secure.php.net/date 2: Post permalink */
		9 => sprintf(__('Lg leads scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview lg leads</a>', 'LeadGenerator'), date_i18n(__('M j, Y @ G:i', 'LeadGenerator'), strtotime($post->post_date)), esc_url($permalink)),
		/* translators: %s: post permalink */
		10 => sprintf(__('Lg leads draft updated. <a target="_blank" href="%s">Preview lg leads</a>', 'LeadGenerator'), esc_url(add_query_arg('preview', 'true', $permalink))),
	];

	return $messages;
}

add_filter('post_updated_messages', 'lgen_leads_updated_messages');

/**
 * Sets the bulk post updated messages for the `lgen_leads` post type.
 *
 * @param  array $bulk_messages Arrays of messages, each keyed by the corresponding post type. Messages are
 *                              keyed with 'updated', 'locked', 'deleted', 'trashed', and 'untrashed'.
 * @param  int[] $bulk_counts   Array of item counts for each message, used to build internationalized strings.
 * @return array Bulk messages for the `lgen_leads` post type.
 */
function lgen_leads_bulk_updated_messages($bulk_messages, $bulk_counts)
{
	global $post;

	$bulk_messages['job'] = [
		/* translators: %s: Number of lg leads. */
		'updated' => _n('%s lg leads updated.', '%s lg leads updated.', $bulk_counts['updated'], 'LeadGenerator'),
		'locked' => (1 === $bulk_counts['locked']) ? __('1 lg leads not updated, somebody is editing it.', 'LeadGenerator') :
			/* translators: %s: Number of lg leads. */
			_n('%s lg leads not updated, somebody is editing it.', '%s lg leads not updated, somebody is editing them.', $bulk_counts['locked'], 'LeadGenerator'),
		/* translators: %s: Number of lg leads. */
		'deleted' => _n('%s lg leads permanently deleted.', '%s lg leads permanently deleted.', $bulk_counts['deleted'], 'LeadGenerator'),
		/* translators: %s: Number of lg leads. */
		'trashed' => _n('%s lg leads moved to the Trash.', '%s lg leads moved to the Trash.', $bulk_counts['trashed'], 'LeadGenerator'),
		/* translators: %s: Number of lg leads. */
		'untrashed' => _n('%s lg leads restored from the Trash.', '%s lg leads restored from the Trash.', $bulk_counts['untrashed'], 'LeadGenerator'),
	];

	return $bulk_messages;
}

add_filter('bulk_post_updated_messages', 'lgen_leads_bulk_updated_messages', 10, 2);



// Register Custom Taxonomy
/**
 * Registers the taxonomy 'job_form_of_employment' for the post type 'job'.
 *
 * @since 1.0.0
 * @return void
 */
function job_form_of_employment()
{

	$labels = array(
		'name' => _x('Anstellungsform', 'Taxonomy General Name', 'LeadGen'),
		'singular_name' => _x('Anstellungsform', 'Taxonomy Singular Name', 'LeadGen'),
		'menu_name' => __('Anstellungsform', 'LeadGen'),
		'all_items' => __('All Items', 'LeadGen'),
		'parent_item' => __('Parent Item', 'LeadGen'),
		'parent_item_colon' => __('Parent Item:', 'LeadGen'),
		'new_item_name' => __('New Item Name', 'LeadGen'),
		'add_new_item' => __('Add New Item', 'LeadGen'),
		'edit_item' => __('Edit Item', 'LeadGen'),
		'update_item' => __('Update Item', 'LeadGen'),
		'view_item' => __('View Item', 'LeadGen'),
		'separate_items_with_commas' => __('Separate items with commas', 'LeadGen'),
		'add_or_remove_items' => __('Add or remove items', 'LeadGen'),
		'choose_from_most_used' => __('Choose from the most used', 'LeadGen'),
		'popular_items' => __('Popular Items', 'LeadGen'),
		'search_items' => __('Search Items', 'LeadGen'),
		'not_found' => __('Not Found', 'LeadGen'),
		'no_terms' => __('No items', 'LeadGen'),
		'items_list' => __('Items list', 'LeadGen'),
		'items_list_navigation' => __('Items list navigation', 'LeadGen'),
	);
	$args = array(
		'labels' => $labels,
		'hierarchical' => true,
		'public' => true,
		'show_ui' => true,
		'show_admin_column' => true,
		'show_in_nav_menus' => true,
		'show_tagcloud' => true,
	);
	register_taxonomy('job_form_of_employment', array('job'), $args);

}
add_action('init', 'job_form_of_employment', 0);


// Register Custom Taxonomy
/**
 * Registers the job_working_time taxonomy for the job post type.
 *
 * @since 1.0.0
 */
function job_working_time()
{

	$labels = array(
		'name' => _x('Arbeitszeiten', 'Taxonomy General Name', 'LeadGen'),
		'singular_name' => _x('Arbeitszeit', 'Taxonomy Singular Name', 'LeadGen'),
		'menu_name' => __('Arbeitszeiten', 'LeadGen'),
		'all_items' => __('All Items', 'LeadGen'),
		'parent_item' => __('Parent Item', 'LeadGen'),
		'parent_item_colon' => __('Parent Item:', 'LeadGen'),
		'new_item_name' => __('New Item Name', 'LeadGen'),
		'add_new_item' => __('Add New Item', 'LeadGen'),
		'edit_item' => __('Edit Item', 'LeadGen'),
		'update_item' => __('Update Item', 'LeadGen'),
		'view_item' => __('View Item', 'LeadGen'),
		'separate_items_with_commas' => __('Separate items with commas', 'LeadGen'),
		'add_or_remove_items' => __('Add or remove items', 'LeadGen'),
		'choose_from_most_used' => __('Choose from the most used', 'LeadGen'),
		'popular_items' => __('Popular Items', 'LeadGen'),
		'search_items' => __('Search Items', 'LeadGen'),
		'not_found' => __('Not Found', 'LeadGen'),
		'no_terms' => __('No items', 'LeadGen'),
		'items_list' => __('Items list', 'LeadGen'),
		'items_list_navigation' => __('Items list navigation', 'LeadGen'),
	);
	$args = array(
		'labels' => $labels,
		'hierarchical' => true,
		'public' => true,
		'show_ui' => true,
		'show_admin_column' => true,
		'show_in_nav_menus' => true,
		'show_tagcloud' => true,
		'rewrite' => array(
			'slug' => 'arbeitszeit'
		),
	);
	register_taxonomy('job_working_time', array('job'), $args);

}
add_action('init', 'job_working_time', 0);

// Register Custom Taxonomy
/**
 * Registers the jobcategory taxonomy for the job and company post types.
 *
 * @since 1.0.0
 */
function job_category()
{

	$labels = array(
		'name' => _x('Job Kategorien', 'Taxonomy General Name', 'LeadGen'),
		'singular_name' => _x('Job Kategorie', 'Taxonomy Singular Name', 'LeadGen'),
		'menu_name' => __('Job Kategorien', 'LeadGen'),
		'all_items' => __('Alle Kategorien', 'LeadGen'),
		'parent_item' => __('Parent Item', 'LeadGen'),
		'parent_item_colon' => __('Parent Item:', 'LeadGen'),
		'new_item_name' => __('New Item Name', 'LeadGen'),
		'add_new_item' => __('Add New Item', 'LeadGen'),
		'edit_item' => __('Edit Item', 'LeadGen'),
		'update_item' => __('Update Item', 'LeadGen'),
		'view_item' => __('View Item', 'LeadGen'),
		'separate_items_with_commas' => __('Separate items with commas', 'LeadGen'),
		'add_or_remove_items' => __('Add or remove items', 'LeadGen'),
		'choose_from_most_used' => __('Choose from the most used', 'LeadGen'),
		'popular_items' => __('Popular Items', 'LeadGen'),
		'search_items' => __('Search Items', 'LeadGen'),
		'not_found' => __('Not Found', 'LeadGen'),
		'no_terms' => __('No items', 'LeadGen'),
		'items_list' => __('Items list', 'LeadGen'),
		'items_list_navigation' => __('Items list navigation', 'LeadGen'),

	);
	$args = array(
		'labels' => $labels,
		'hierarchical' => true,
		'public' => true,
		'show_ui' => true,
		'show_admin_column' => true,
		'show_in_nav_menus' => true,
		'show_tagcloud' => true,
		'rewrite' => array(
			'slug' => 'stellenangebote'
		),
	);
	register_taxonomy('jobcategory', array('job', 'company'), $args);

}
add_action('init', 'job_category', 0);


// Register Custom Taxonomy
/**
 * Registers the job_type taxonomy for the job post type.
 *
 * @since 1.0.0
 */
function job_type()
{

	$labels = array(
		'name' => _x('Anstellungsformen', 'Taxonomy General Name', 'LeadGen'),
		'singular_name' => _x('Anstellungsform', 'Taxonomy Singular Name', 'LeadGen'),
		'menu_name' => __('Anstellungsform', 'LeadGen'),
		'all_items' => __('Alle Anstellungsformen', 'LeadGen'),
		'parent_item' => __('Parent Item', 'LeadGen'),
		'parent_item_colon' => __('Parent Item:', 'LeadGen'),
		'new_item_name' => __('New Item Name', 'LeadGen'),
		'add_new_item' => __('Add New Item', 'LeadGen'),
		'edit_item' => __('Edit Item', 'LeadGen'),
		'update_item' => __('Update Item', 'LeadGen'),
		'view_item' => __('View Item', 'LeadGen'),
		'separate_items_with_commas' => __('Separate items with commas', 'LeadGen'),
		'add_or_remove_items' => __('Add or remove items', 'LeadGen'),
		'choose_from_most_used' => __('Choose from the most used', 'LeadGen'),
		'popular_items' => __('Popular Items', 'LeadGen'),
		'search_items' => __('Search Items', 'LeadGen'),
		'not_found' => __('Not Found', 'LeadGen'),
		'no_terms' => __('No items', 'LeadGen'),
		'items_list' => __('Items list', 'LeadGen'),
		'items_list_navigation' => __('Items list navigation', 'LeadGen'),
	);
	$args = array(
		'labels' => $labels,
		'hierarchical' => true,
		'public' => true,
		'show_ui' => true,
		'show_admin_column' => true,
		'show_in_nav_menus' => true,
		'show_tagcloud' => true,
		'rewrite' => array(
			'slug' => 'job-art'
		),
	);
	register_taxonomy('job_type', array('job'), $args);

}
add_action('init', 'job_type', 0);

// Register Custom Taxonomy
/**
 * Registers the job_district taxonomy for the job post type.
 *
 * @since 1.0.0
 *
 * @return void
 */
function job_district()
{

	$labels = array(
		'name' => _x('job_districts', 'Taxonomy General Name', 'LeadGen'),
		'singular_name' => _x('job_districts', 'Taxonomy Singular Name', 'LeadGen'),
		'menu_name' => __('job_districts', 'LeadGen'),
		'all_items' => __('All Items', 'LeadGen'),
		'parent_item' => __('Parent Item', 'LeadGen'),
		'parent_item_colon' => __('Parent Item:', 'LeadGen'),
		'new_item_name' => __('New Item Name', 'LeadGen'),
		'add_new_item' => __('Add New Item', 'LeadGen'),
		'edit_item' => __('Edit Item', 'LeadGen'),
		'update_item' => __('Update Item', 'LeadGen'),
		'view_item' => __('View Item', 'LeadGen'),
		'separate_items_with_commas' => __('Separate items with commas', 'LeadGen'),
		'add_or_remove_items' => __('Add or remove items', 'LeadGen'),
		'choose_from_most_used' => __('Choose from the most used', 'LeadGen'),
		'popular_items' => __('Popular Items', 'LeadGen'),
		'search_items' => __('Search Items', 'LeadGen'),
		'not_found' => __('Not Found', 'LeadGen'),
		'no_terms' => __('No items', 'LeadGen'),
		'items_list' => __('Items list', 'LeadGen'),
		'items_list_navigation' => __('Items list navigation', 'LeadGen'),
	);
	$args = array(
		'labels' => $labels,
		'hierarchical' => true,
		'public' => true,
		'show_ui' => true,
		'show_admin_column' => true,
		'show_in_nav_menus' => true,
		'show_tagcloud' => true,
	);
	register_taxonomy('job_district', array('job'), $args);

}
add_action('init', 'job_district', 0);

