<?php

namespace Lightweb_Media\Lightweb_Media_Admin_Pages;

defined( 'ABSPATH' ) || exit;

class LWM_Admin_Forms {
    public function __construct(
        private string $option_name = '', 
        private array $fields = [],
        private string $option_group = '',
        private string $option_page = '',
        private string $option_section = ''
    ) {
        $this->option_name = $option_name;
        $this->option_group = $option_name . '_options_group';
        $this->option_page = $option_name . '_options_page';
        $this->option_section = $option_name . '_options_section';
        $this->fields = $fields;

        add_action('admin_init', [$this, 'register_settings']);
    }

    /**
     * Register the settings
     * 
     * @return void
     */
    public function register_settings(): void {
        register_setting($this->option_group, $this->option_name);

        add_settings_section(
            $this->option_section,
            '',
            '__return_false',
            $this->option_page
        );       

        foreach( $this->fields as $field ) {
            add_settings_field(
                $field['id'],
                $field['title'],
                [$this, 'render_text_field'],
                $this->option_page,
                $this->option_section,
                [
                    'id' => $field['id'],
                ]
            );
        }
    }

    /**
     * Render the text field
     * 
     * @param array $args
     * @return void 
     */
    public function render_text_field( $args ): void {
        $options = get_option($this->option_name);
        $value = $options[$args['id']] ?? '';

        echo '<input type="text" id="' . $args['id'] . '" name="' . esc_attr($this->option_name) . '[' . $args['id'] . ']" value="' . esc_attr($value) . '" />';
        echo '<p><small>' . esc_attr( $args['id'] ) . '</small></p>';
    }

    /**
     * Render the options page
     * 
     * @return void
     */
    public function render_options_page(): void {
        echo '<form method="post" action="options.php">';
        settings_fields($this->option_group);
        do_settings_sections($this->option_page);
        submit_button();
        echo '</form>';
    }
}