<?php

namespace Lightweb_Media\Lightweb_Media_Admin_Pages;

use Lightweb_Media\Lightweb_Media_Plugin_Sidebar\LWM_Plugin_Sidebar;

defined( 'ABSPATH' ) || exit;

class LWM_Admin_Pages {

    public function __construct(
        private string $menu_slug = '', 
        private string $page_title = '', 
        private string $menu_title = '', 
        private string $capability = 'manage_options', 
        private $content_callback = null,
        private array $subpages = []
    ) {
        $this->menu_slug = $menu_slug;
        $this->page_title = $page_title;
        $this->menu_title = $menu_title;
        $this->capability = $capability;
        $this->content_callback = $content_callback;

        add_action('admin_menu', [$this, 'register_admin_pages']);
    }

    /**
     * Add a subpage to the admin page
     * 
     * @param string $menu_slug
     * @param string $page_title
     * @param string $menu_title
     * @param callable $content_callback
     * @return void
     */
    public function add_subpage($menu_slug, $page_title, $menu_title, $content_callback): void {
        $this->subpages[] = [
            'menu_slug'       => $menu_slug,
            'page_title'      => $page_title,
            'menu_title'      => $menu_title,
            'content_callback' => $content_callback,
        ];
    }

    /**
     * Register the admin pages
     * 
     * @return void
     */
    public function register_admin_pages(): void {
        add_menu_page(
            $this->page_title,
            $this->menu_title,
            $this->capability,
            $this->menu_slug,
            [$this, 'render_page']
        );

        foreach ($this->subpages as $subpage) {
            add_submenu_page(
                $this->menu_slug,
                $subpage['page_title'],
                $subpage['menu_title'],
                $this->capability,
                $subpage['menu_slug'],
                function () use ($subpage) {
                    $this->render_page($subpage['content_callback']);
                }
            );
        }
    }

    /**
     * Render the admin page
     * 
     * @param callable $content_callback
     * @return void
     */
    public function render_page($content_callback = null): void {
        $content_callback = $content_callback ?: $this->content_callback;

        ob_start();

        echo '<style>';
        require_once dirname( __DIR__ ) . '/assets/css/admin-pages.css';
        echo '</style>';

        echo '<div class="wrap lwm-admin-pages ' . $this->menu_slug . '">';

        echo '<div class="page-content">';

        if ( is_callable( $content_callback ) ) {
            call_user_func($content_callback);
        }

        echo '</div>';

        LWM_Plugin_Sidebar::get_instance()->output();

        echo '</div>';

        echo ob_get_clean();
    }

}